@@ -35,7 +35,7 @@ impl From<crate::W<CTRL_SPEC>> for W {
     }
 }
 #[doc = "Field `cpu_adc_start` reader - Start ADC Conversion"]
-pub struct CPU_ADC_START_R(crate::FieldReader<bool, bool>);
+pub struct CPU_ADC_START_R(crate::FieldReader<bool>);
 impl CPU_ADC_START_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl CPU_ADC_START_R {
     }
 }
 impl core::ops::Deref for CPU_ADC_START_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,12 +67,12 @@ impl<'a> CPU_ADC_START_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `adc_pu` reader - ADC Power Up"]
-pub struct ADC_PU_R(crate::FieldReader<bool, bool>);
+pub struct ADC_PU_R(crate::FieldReader<bool>);
 impl ADC_PU_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -80,7 +80,7 @@ impl ADC_PU_R {
     }
 }
 impl core::ops::Deref for ADC_PU_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -104,12 +104,12 @@ impl<'a> ADC_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `buf_pu` reader - ADC Input Buffer Power Up"]
-pub struct BUF_PU_R(crate::FieldReader<bool, bool>);
+pub struct BUF_PU_R(crate::FieldReader<bool>);
 impl BUF_PU_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -117,7 +117,7 @@ impl BUF_PU_R {
     }
 }
 impl core::ops::Deref for BUF_PU_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -141,12 +141,12 @@ impl<'a> BUF_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `adc_refbuf_pu` reader - ADC Reference Buffer Power Up"]
-pub struct ADC_REFBUF_PU_R(crate::FieldReader<bool, bool>);
+pub struct ADC_REFBUF_PU_R(crate::FieldReader<bool>);
 impl ADC_REFBUF_PU_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -154,7 +154,7 @@ impl ADC_REFBUF_PU_R {
     }
 }
 impl core::ops::Deref for ADC_REFBUF_PU_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -178,12 +178,12 @@ impl<'a> ADC_REFBUF_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `adc_chgpump_pu` reader - ADC Charge Pump Power Up"]
-pub struct ADC_CHGPUMP_PU_R(crate::FieldReader<bool, bool>);
+pub struct ADC_CHGPUMP_PU_R(crate::FieldReader<bool>);
 impl ADC_CHGPUMP_PU_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -191,7 +191,7 @@ impl ADC_CHGPUMP_PU_R {
     }
 }
 impl core::ops::Deref for ADC_CHGPUMP_PU_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -215,12 +215,12 @@ impl<'a> ADC_CHGPUMP_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `buf_chop_dis` reader - ADC Input Buffer Chop Disable (INTERNAL ONLY)"]
-pub struct BUF_CHOP_DIS_R(crate::FieldReader<bool, bool>);
+pub struct BUF_CHOP_DIS_R(crate::FieldReader<bool>);
 impl BUF_CHOP_DIS_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -228,7 +228,7 @@ impl BUF_CHOP_DIS_R {
     }
 }
 impl core::ops::Deref for BUF_CHOP_DIS_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -252,12 +252,12 @@ impl<'a> BUF_CHOP_DIS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `buf_pump_dis` reader - Disable Use of Charge Pump Output by Input Buffer (INTERNAL)"]
-pub struct BUF_PUMP_DIS_R(crate::FieldReader<bool, bool>);
+pub struct BUF_PUMP_DIS_R(crate::FieldReader<bool>);
 impl BUF_PUMP_DIS_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -265,7 +265,7 @@ impl BUF_PUMP_DIS_R {
     }
 }
 impl core::ops::Deref for BUF_PUMP_DIS_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -289,12 +289,12 @@ impl<'a> BUF_PUMP_DIS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `buf_bypass` reader - Bypass Input Buffer"]
-pub struct BUF_BYPASS_R(crate::FieldReader<bool, bool>);
+pub struct BUF_BYPASS_R(crate::FieldReader<bool>);
 impl BUF_BYPASS_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -302,7 +302,7 @@ impl BUF_BYPASS_R {
     }
 }
 impl core::ops::Deref for BUF_BYPASS_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -326,12 +326,12 @@ impl<'a> BUF_BYPASS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `adc_refscl` reader - ADC Reference Scale"]
-pub struct ADC_REFSCL_R(crate::FieldReader<bool, bool>);
+pub struct ADC_REFSCL_R(crate::FieldReader<bool>);
 impl ADC_REFSCL_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -339,7 +339,7 @@ impl ADC_REFSCL_R {
     }
 }
 impl core::ops::Deref for ADC_REFSCL_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -363,12 +363,12 @@ impl<'a> ADC_REFSCL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `adc_scale` reader - ADC Scale"]
-pub struct ADC_SCALE_R(crate::FieldReader<bool, bool>);
+pub struct ADC_SCALE_R(crate::FieldReader<bool>);
 impl ADC_SCALE_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -376,7 +376,7 @@ impl ADC_SCALE_R {
     }
 }
 impl core::ops::Deref for ADC_SCALE_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -400,12 +400,12 @@ impl<'a> ADC_SCALE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `adc_refsel` reader - ADC Reference (VRef) Select (INTERNAL ONLY)"]
-pub struct ADC_REFSEL_R(crate::FieldReader<bool, bool>);
+pub struct ADC_REFSEL_R(crate::FieldReader<bool>);
 impl ADC_REFSEL_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -413,7 +413,7 @@ impl ADC_REFSEL_R {
     }
 }
 impl core::ops::Deref for ADC_REFSEL_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -437,12 +437,12 @@ impl<'a> ADC_REFSEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `adc_clk_en` reader - ADC Clock Enable"]
-pub struct ADC_CLK_EN_R(crate::FieldReader<bool, bool>);
+pub struct ADC_CLK_EN_R(crate::FieldReader<bool>);
 impl ADC_CLK_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -450,7 +450,7 @@ impl ADC_CLK_EN_R {
     }
 }
 impl core::ops::Deref for ADC_CLK_EN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -474,12 +474,12 @@ impl<'a> ADC_CLK_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `adc_chsel` reader - ADC Channel Select"]
-pub struct ADC_CHSEL_R(crate::FieldReader<u8, u8>);
+pub struct ADC_CHSEL_R(crate::FieldReader<u8>);
 impl ADC_CHSEL_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -487,7 +487,7 @@ impl ADC_CHSEL_R {
     }
 }
 impl core::ops::Deref for ADC_CHSEL_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -506,7 +506,7 @@ impl<'a> ADC_CHSEL_W<'a> {
     }
 }
 #[doc = "Field `adc_xref` reader - Enable Use of ADC External Reference"]
-pub struct ADC_XREF_R(crate::FieldReader<bool, bool>);
+pub struct ADC_XREF_R(crate::FieldReader<bool>);
 impl ADC_XREF_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -514,7 +514,7 @@ impl ADC_XREF_R {
     }
 }
 impl core::ops::Deref for ADC_XREF_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -538,12 +538,12 @@ impl<'a> ADC_XREF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
 #[doc = "Field `adc_dataalign` reader - ADC Data Alignment Select"]
-pub struct ADC_DATAALIGN_R(crate::FieldReader<bool, bool>);
+pub struct ADC_DATAALIGN_R(crate::FieldReader<bool>);
 impl ADC_DATAALIGN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -551,7 +551,7 @@ impl ADC_DATAALIGN_R {
     }
 }
 impl core::ops::Deref for ADC_DATAALIGN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -575,12 +575,12 @@ impl<'a> ADC_DATAALIGN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
 #[doc = "Field `afe_pwr_up_dly` reader - Delay from ADC Powerup Until ADC Ready Asserted"]
-pub struct AFE_PWR_UP_DLY_R(crate::FieldReader<u8, u8>);
+pub struct AFE_PWR_UP_DLY_R(crate::FieldReader<u8>);
 impl AFE_PWR_UP_DLY_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -588,7 +588,7 @@ impl AFE_PWR_UP_DLY_R {
     }
 }
 impl core::ops::Deref for AFE_PWR_UP_DLY_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -610,62 +610,62 @@ impl R {
     #[doc = "Bit 0 - Start ADC Conversion"]
     #[inline(always)]
     pub fn cpu_adc_start(&self) -> CPU_ADC_START_R {
-        CPU_ADC_START_R::new((self.bits & 0x01) != 0)
+        CPU_ADC_START_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - ADC Power Up"]
     #[inline(always)]
     pub fn adc_pu(&self) -> ADC_PU_R {
-        ADC_PU_R::new(((self.bits >> 1) & 0x01) != 0)
+        ADC_PU_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - ADC Input Buffer Power Up"]
     #[inline(always)]
     pub fn buf_pu(&self) -> BUF_PU_R {
-        BUF_PU_R::new(((self.bits >> 2) & 0x01) != 0)
+        BUF_PU_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - ADC Reference Buffer Power Up"]
     #[inline(always)]
     pub fn adc_refbuf_pu(&self) -> ADC_REFBUF_PU_R {
-        ADC_REFBUF_PU_R::new(((self.bits >> 3) & 0x01) != 0)
+        ADC_REFBUF_PU_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - ADC Charge Pump Power Up"]
     #[inline(always)]
     pub fn adc_chgpump_pu(&self) -> ADC_CHGPUMP_PU_R {
-        ADC_CHGPUMP_PU_R::new(((self.bits >> 4) & 0x01) != 0)
+        ADC_CHGPUMP_PU_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - ADC Input Buffer Chop Disable (INTERNAL ONLY)"]
     #[inline(always)]
     pub fn buf_chop_dis(&self) -> BUF_CHOP_DIS_R {
-        BUF_CHOP_DIS_R::new(((self.bits >> 5) & 0x01) != 0)
+        BUF_CHOP_DIS_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - Disable Use of Charge Pump Output by Input Buffer (INTERNAL)"]
     #[inline(always)]
     pub fn buf_pump_dis(&self) -> BUF_PUMP_DIS_R {
-        BUF_PUMP_DIS_R::new(((self.bits >> 6) & 0x01) != 0)
+        BUF_PUMP_DIS_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - Bypass Input Buffer"]
     #[inline(always)]
     pub fn buf_bypass(&self) -> BUF_BYPASS_R {
-        BUF_BYPASS_R::new(((self.bits >> 7) & 0x01) != 0)
+        BUF_BYPASS_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - ADC Reference Scale"]
     #[inline(always)]
     pub fn adc_refscl(&self) -> ADC_REFSCL_R {
-        ADC_REFSCL_R::new(((self.bits >> 8) & 0x01) != 0)
+        ADC_REFSCL_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - ADC Scale"]
     #[inline(always)]
     pub fn adc_scale(&self) -> ADC_SCALE_R {
-        ADC_SCALE_R::new(((self.bits >> 9) & 0x01) != 0)
+        ADC_SCALE_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - ADC Reference (VRef) Select (INTERNAL ONLY)"]
     #[inline(always)]
     pub fn adc_refsel(&self) -> ADC_REFSEL_R {
-        ADC_REFSEL_R::new(((self.bits >> 10) & 0x01) != 0)
+        ADC_REFSEL_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - ADC Clock Enable"]
     #[inline(always)]
     pub fn adc_clk_en(&self) -> ADC_CLK_EN_R {
-        ADC_CLK_EN_R::new(((self.bits >> 11) & 0x01) != 0)
+        ADC_CLK_EN_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bits 12:15 - ADC Channel Select"]
     #[inline(always)]
@@ -675,12 +675,12 @@ impl R {
     #[doc = "Bit 16 - Enable Use of ADC External Reference"]
     #[inline(always)]
     pub fn adc_xref(&self) -> ADC_XREF_R {
-        ADC_XREF_R::new(((self.bits >> 16) & 0x01) != 0)
+        ADC_XREF_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - ADC Data Alignment Select"]
     #[inline(always)]
     pub fn adc_dataalign(&self) -> ADC_DATAALIGN_R {
-        ADC_DATAALIGN_R::new(((self.bits >> 17) & 0x01) != 0)
+        ADC_DATAALIGN_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bits 24:31 - Delay from ADC Powerup Until ADC Ready Asserted"]
     #[inline(always)]
