@@ -35,7 +35,7 @@ impl From<crate::W<CLK_GATE_CTRL1_SPEC>> for W {
     }
 }
 #[doc = "Field `watchdog1_clk_gater` reader - Clock Gating Control for Watchdog Timer 1"]
-pub struct WATCHDOG1_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct WATCHDOG1_CLK_GATER_R(crate::FieldReader<u8>);
 impl WATCHDOG1_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -43,7 +43,7 @@ impl WATCHDOG1_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for WATCHDOG1_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -57,12 +57,12 @@ impl<'a> WATCHDOG1_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
+        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
         self.w
     }
 }
 #[doc = "Field `gpio_clk_gater` reader - Clock Gating Control for GPIO Ports"]
-pub struct GPIO_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct GPIO_CLK_GATER_R(crate::FieldReader<u8>);
 impl GPIO_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -70,7 +70,7 @@ impl GPIO_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for GPIO_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -84,12 +84,12 @@ impl<'a> GPIO_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 2)) | ((value as u32 & 0x03) << 2);
+        self.w.bits = (self.w.bits & !(3 << 2)) | ((value as u32 & 3) << 2);
         self.w
     }
 }
 #[doc = "Field `timer0_clk_gater` reader - Clock Gating Control for Timer/Counter Module 0"]
-pub struct TIMER0_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct TIMER0_CLK_GATER_R(crate::FieldReader<u8>);
 impl TIMER0_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -97,7 +97,7 @@ impl TIMER0_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for TIMER0_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -111,12 +111,12 @@ impl<'a> TIMER0_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 4)) | ((value as u32 & 0x03) << 4);
+        self.w.bits = (self.w.bits & !(3 << 4)) | ((value as u32 & 3) << 4);
         self.w
     }
 }
 #[doc = "Field `timer1_clk_gater` reader - Clock Gating Control for Timer/Counter Module 1"]
-pub struct TIMER1_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct TIMER1_CLK_GATER_R(crate::FieldReader<u8>);
 impl TIMER1_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -124,7 +124,7 @@ impl TIMER1_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for TIMER1_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -138,12 +138,12 @@ impl<'a> TIMER1_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 6)) | ((value as u32 & 0x03) << 6);
+        self.w.bits = (self.w.bits & !(3 << 6)) | ((value as u32 & 3) << 6);
         self.w
     }
 }
 #[doc = "Field `timer2_clk_gater` reader - Clock Gating Control for Timer/Counter Module 2"]
-pub struct TIMER2_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct TIMER2_CLK_GATER_R(crate::FieldReader<u8>);
 impl TIMER2_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -151,7 +151,7 @@ impl TIMER2_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for TIMER2_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -165,12 +165,12 @@ impl<'a> TIMER2_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 8)) | ((value as u32 & 0x03) << 8);
+        self.w.bits = (self.w.bits & !(3 << 8)) | ((value as u32 & 3) << 8);
         self.w
     }
 }
 #[doc = "Field `timer3_clk_gater` reader - Clock Gating Control for Timer/Counter Module 3"]
-pub struct TIMER3_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct TIMER3_CLK_GATER_R(crate::FieldReader<u8>);
 impl TIMER3_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -178,7 +178,7 @@ impl TIMER3_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for TIMER3_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -192,12 +192,12 @@ impl<'a> TIMER3_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 10)) | ((value as u32 & 0x03) << 10);
+        self.w.bits = (self.w.bits & !(3 << 10)) | ((value as u32 & 3) << 10);
         self.w
     }
 }
 #[doc = "Field `timer4_clk_gater` reader - Clock Gating Control for Timer/Counter Module 4"]
-pub struct TIMER4_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct TIMER4_CLK_GATER_R(crate::FieldReader<u8>);
 impl TIMER4_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -205,7 +205,7 @@ impl TIMER4_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for TIMER4_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -219,12 +219,12 @@ impl<'a> TIMER4_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 12)) | ((value as u32 & 0x03) << 12);
+        self.w.bits = (self.w.bits & !(3 << 12)) | ((value as u32 & 3) << 12);
         self.w
     }
 }
 #[doc = "Field `timer5_clk_gater` reader - Clock Gating Control for Timer/Counter Module 5"]
-pub struct TIMER5_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct TIMER5_CLK_GATER_R(crate::FieldReader<u8>);
 impl TIMER5_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -232,7 +232,7 @@ impl TIMER5_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for TIMER5_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -246,12 +246,12 @@ impl<'a> TIMER5_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 14)) | ((value as u32 & 0x03) << 14);
+        self.w.bits = (self.w.bits & !(3 << 14)) | ((value as u32 & 3) << 14);
         self.w
     }
 }
 #[doc = "Field `pulsetrain_clk_gater` reader - Clock Gating Control for Pulse Train Generators"]
-pub struct PULSETRAIN_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct PULSETRAIN_CLK_GATER_R(crate::FieldReader<u8>);
 impl PULSETRAIN_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -259,7 +259,7 @@ impl PULSETRAIN_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for PULSETRAIN_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -273,12 +273,12 @@ impl<'a> PULSETRAIN_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 16)) | ((value as u32 & 0x03) << 16);
+        self.w.bits = (self.w.bits & !(3 << 16)) | ((value as u32 & 3) << 16);
         self.w
     }
 }
 #[doc = "Field `uart0_clk_gater` reader - Clock Gating Control for UART 0"]
-pub struct UART0_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct UART0_CLK_GATER_R(crate::FieldReader<u8>);
 impl UART0_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -286,7 +286,7 @@ impl UART0_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for UART0_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -300,12 +300,12 @@ impl<'a> UART0_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 18)) | ((value as u32 & 0x03) << 18);
+        self.w.bits = (self.w.bits & !(3 << 18)) | ((value as u32 & 3) << 18);
         self.w
     }
 }
 #[doc = "Field `uart1_clk_gater` reader - Clock Gating Control for UART 1"]
-pub struct UART1_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct UART1_CLK_GATER_R(crate::FieldReader<u8>);
 impl UART1_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -313,7 +313,7 @@ impl UART1_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for UART1_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -327,12 +327,12 @@ impl<'a> UART1_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 20)) | ((value as u32 & 0x03) << 20);
+        self.w.bits = (self.w.bits & !(3 << 20)) | ((value as u32 & 3) << 20);
         self.w
     }
 }
 #[doc = "Field `uart2_clk_gater` reader - Clock Gating Control for UART 2"]
-pub struct UART2_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct UART2_CLK_GATER_R(crate::FieldReader<u8>);
 impl UART2_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -340,7 +340,7 @@ impl UART2_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for UART2_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -354,12 +354,12 @@ impl<'a> UART2_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 22)) | ((value as u32 & 0x03) << 22);
+        self.w.bits = (self.w.bits & !(3 << 22)) | ((value as u32 & 3) << 22);
         self.w
     }
 }
 #[doc = "Field `uart3_clk_gater` reader - Clock Gating Control for UART 3"]
-pub struct UART3_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct UART3_CLK_GATER_R(crate::FieldReader<u8>);
 impl UART3_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -367,7 +367,7 @@ impl UART3_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for UART3_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -381,12 +381,12 @@ impl<'a> UART3_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 24)) | ((value as u32 & 0x03) << 24);
+        self.w.bits = (self.w.bits & !(3 << 24)) | ((value as u32 & 3) << 24);
         self.w
     }
 }
 #[doc = "Field `i2cm0_clk_gater` reader - Clock Gating Control for I2C Master 0"]
-pub struct I2CM0_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct I2CM0_CLK_GATER_R(crate::FieldReader<u8>);
 impl I2CM0_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -394,7 +394,7 @@ impl I2CM0_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for I2CM0_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -408,12 +408,12 @@ impl<'a> I2CM0_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 26)) | ((value as u32 & 0x03) << 26);
+        self.w.bits = (self.w.bits & !(3 << 26)) | ((value as u32 & 3) << 26);
         self.w
     }
 }
 #[doc = "Field `i2cm1_clk_gater` reader - Clock Gating Control for I2C Master 1"]
-pub struct I2CM1_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct I2CM1_CLK_GATER_R(crate::FieldReader<u8>);
 impl I2CM1_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -421,7 +421,7 @@ impl I2CM1_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for I2CM1_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -435,12 +435,12 @@ impl<'a> I2CM1_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 28)) | ((value as u32 & 0x03) << 28);
+        self.w.bits = (self.w.bits & !(3 << 28)) | ((value as u32 & 3) << 28);
         self.w
     }
 }
 #[doc = "Field `i2cm2_clk_gater` reader - Clock Gating Control for I2C Master 2"]
-pub struct I2CM2_CLK_GATER_R(crate::FieldReader<u8, u8>);
+pub struct I2CM2_CLK_GATER_R(crate::FieldReader<u8>);
 impl I2CM2_CLK_GATER_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -448,7 +448,7 @@ impl I2CM2_CLK_GATER_R {
     }
 }
 impl core::ops::Deref for I2CM2_CLK_GATER_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -462,7 +462,7 @@ impl<'a> I2CM2_CLK_GATER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 30)) | ((value as u32 & 0x03) << 30);
+        self.w.bits = (self.w.bits & !(3 << 30)) | ((value as u32 & 3) << 30);
         self.w
     }
 }
@@ -470,82 +470,82 @@ impl R {
     #[doc = "Bits 0:1 - Clock Gating Control for Watchdog Timer 1"]
     #[inline(always)]
     pub fn watchdog1_clk_gater(&self) -> WATCHDOG1_CLK_GATER_R {
-        WATCHDOG1_CLK_GATER_R::new((self.bits & 0x03) as u8)
+        WATCHDOG1_CLK_GATER_R::new((self.bits & 3) as u8)
     }
     #[doc = "Bits 2:3 - Clock Gating Control for GPIO Ports"]
     #[inline(always)]
     pub fn gpio_clk_gater(&self) -> GPIO_CLK_GATER_R {
-        GPIO_CLK_GATER_R::new(((self.bits >> 2) & 0x03) as u8)
+        GPIO_CLK_GATER_R::new(((self.bits >> 2) & 3) as u8)
     }
     #[doc = "Bits 4:5 - Clock Gating Control for Timer/Counter Module 0"]
     #[inline(always)]
     pub fn timer0_clk_gater(&self) -> TIMER0_CLK_GATER_R {
-        TIMER0_CLK_GATER_R::new(((self.bits >> 4) & 0x03) as u8)
+        TIMER0_CLK_GATER_R::new(((self.bits >> 4) & 3) as u8)
     }
     #[doc = "Bits 6:7 - Clock Gating Control for Timer/Counter Module 1"]
     #[inline(always)]
     pub fn timer1_clk_gater(&self) -> TIMER1_CLK_GATER_R {
-        TIMER1_CLK_GATER_R::new(((self.bits >> 6) & 0x03) as u8)
+        TIMER1_CLK_GATER_R::new(((self.bits >> 6) & 3) as u8)
     }
     #[doc = "Bits 8:9 - Clock Gating Control for Timer/Counter Module 2"]
     #[inline(always)]
     pub fn timer2_clk_gater(&self) -> TIMER2_CLK_GATER_R {
-        TIMER2_CLK_GATER_R::new(((self.bits >> 8) & 0x03) as u8)
+        TIMER2_CLK_GATER_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 10:11 - Clock Gating Control for Timer/Counter Module 3"]
     #[inline(always)]
     pub fn timer3_clk_gater(&self) -> TIMER3_CLK_GATER_R {
-        TIMER3_CLK_GATER_R::new(((self.bits >> 10) & 0x03) as u8)
+        TIMER3_CLK_GATER_R::new(((self.bits >> 10) & 3) as u8)
     }
     #[doc = "Bits 12:13 - Clock Gating Control for Timer/Counter Module 4"]
     #[inline(always)]
     pub fn timer4_clk_gater(&self) -> TIMER4_CLK_GATER_R {
-        TIMER4_CLK_GATER_R::new(((self.bits >> 12) & 0x03) as u8)
+        TIMER4_CLK_GATER_R::new(((self.bits >> 12) & 3) as u8)
     }
     #[doc = "Bits 14:15 - Clock Gating Control for Timer/Counter Module 5"]
     #[inline(always)]
     pub fn timer5_clk_gater(&self) -> TIMER5_CLK_GATER_R {
-        TIMER5_CLK_GATER_R::new(((self.bits >> 14) & 0x03) as u8)
+        TIMER5_CLK_GATER_R::new(((self.bits >> 14) & 3) as u8)
     }
     #[doc = "Bits 16:17 - Clock Gating Control for Pulse Train Generators"]
     #[inline(always)]
     pub fn pulsetrain_clk_gater(&self) -> PULSETRAIN_CLK_GATER_R {
-        PULSETRAIN_CLK_GATER_R::new(((self.bits >> 16) & 0x03) as u8)
+        PULSETRAIN_CLK_GATER_R::new(((self.bits >> 16) & 3) as u8)
     }
     #[doc = "Bits 18:19 - Clock Gating Control for UART 0"]
     #[inline(always)]
     pub fn uart0_clk_gater(&self) -> UART0_CLK_GATER_R {
-        UART0_CLK_GATER_R::new(((self.bits >> 18) & 0x03) as u8)
+        UART0_CLK_GATER_R::new(((self.bits >> 18) & 3) as u8)
     }
     #[doc = "Bits 20:21 - Clock Gating Control for UART 1"]
     #[inline(always)]
     pub fn uart1_clk_gater(&self) -> UART1_CLK_GATER_R {
-        UART1_CLK_GATER_R::new(((self.bits >> 20) & 0x03) as u8)
+        UART1_CLK_GATER_R::new(((self.bits >> 20) & 3) as u8)
     }
     #[doc = "Bits 22:23 - Clock Gating Control for UART 2"]
     #[inline(always)]
     pub fn uart2_clk_gater(&self) -> UART2_CLK_GATER_R {
-        UART2_CLK_GATER_R::new(((self.bits >> 22) & 0x03) as u8)
+        UART2_CLK_GATER_R::new(((self.bits >> 22) & 3) as u8)
     }
     #[doc = "Bits 24:25 - Clock Gating Control for UART 3"]
     #[inline(always)]
     pub fn uart3_clk_gater(&self) -> UART3_CLK_GATER_R {
-        UART3_CLK_GATER_R::new(((self.bits >> 24) & 0x03) as u8)
+        UART3_CLK_GATER_R::new(((self.bits >> 24) & 3) as u8)
     }
     #[doc = "Bits 26:27 - Clock Gating Control for I2C Master 0"]
     #[inline(always)]
     pub fn i2cm0_clk_gater(&self) -> I2CM0_CLK_GATER_R {
-        I2CM0_CLK_GATER_R::new(((self.bits >> 26) & 0x03) as u8)
+        I2CM0_CLK_GATER_R::new(((self.bits >> 26) & 3) as u8)
     }
     #[doc = "Bits 28:29 - Clock Gating Control for I2C Master 1"]
     #[inline(always)]
     pub fn i2cm1_clk_gater(&self) -> I2CM1_CLK_GATER_R {
-        I2CM1_CLK_GATER_R::new(((self.bits >> 28) & 0x03) as u8)
+        I2CM1_CLK_GATER_R::new(((self.bits >> 28) & 3) as u8)
     }
     #[doc = "Bits 30:31 - Clock Gating Control for I2C Master 2"]
     #[inline(always)]
     pub fn i2cm2_clk_gater(&self) -> I2CM2_CLK_GATER_R {
-        I2CM2_CLK_GATER_R::new(((self.bits >> 30) & 0x03) as u8)
+        I2CM2_CLK_GATER_R::new(((self.bits >> 30) & 3) as u8)
     }
 }
 impl W {
