@@ -35,7 +35,7 @@ impl From<crate::W<CM4_START_CLK_EN1_SPEC>> for W {
     }
 }
 #[doc = "Field `ints` reader - Interrupt Sources 32-63"]
-pub struct INTS_R(crate::FieldReader<u32, u32>);
+pub struct INTS_R(crate::FieldReader<u32>);
 impl INTS_R {
     #[inline(always)]
     pub(crate) fn new(bits: u32) -> Self {
@@ -43,7 +43,7 @@ impl INTS_R {
     }
 }
 impl core::ops::Deref for INTS_R {
-    type Target = crate::FieldReader<u32, u32>;
+    type Target = crate::FieldReader<u32>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
