@@ -35,7 +35,7 @@ impl From<crate::W<INTEN_SPEC>> for W {
     }
 }
 #[doc = "Field `byte0` reader - Updated Byte 0"]
-pub struct BYTE0_R(crate::FieldReader<bool, bool>);
+pub struct BYTE0_R(crate::FieldReader<bool>);
 impl BYTE0_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl BYTE0_R {
     }
 }
 impl core::ops::Deref for BYTE0_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,12 +67,12 @@ impl<'a> BYTE0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `byte1` reader - Updated Byte 1"]
-pub struct BYTE1_R(crate::FieldReader<bool, bool>);
+pub struct BYTE1_R(crate::FieldReader<bool>);
 impl BYTE1_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -80,7 +80,7 @@ impl BYTE1_R {
     }
 }
 impl core::ops::Deref for BYTE1_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -104,12 +104,12 @@ impl<'a> BYTE1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `byte2` reader - Updated Byte 2"]
-pub struct BYTE2_R(crate::FieldReader<bool, bool>);
+pub struct BYTE2_R(crate::FieldReader<bool>);
 impl BYTE2_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -117,7 +117,7 @@ impl BYTE2_R {
     }
 }
 impl core::ops::Deref for BYTE2_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -141,12 +141,12 @@ impl<'a> BYTE2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `byte3` reader - Updated Byte 3"]
-pub struct BYTE3_R(crate::FieldReader<bool, bool>);
+pub struct BYTE3_R(crate::FieldReader<bool>);
 impl BYTE3_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -154,7 +154,7 @@ impl BYTE3_R {
     }
 }
 impl core::ops::Deref for BYTE3_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -178,12 +178,12 @@ impl<'a> BYTE3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `byte4` reader - Updated Byte 4"]
-pub struct BYTE4_R(crate::FieldReader<bool, bool>);
+pub struct BYTE4_R(crate::FieldReader<bool>);
 impl BYTE4_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -191,7 +191,7 @@ impl BYTE4_R {
     }
 }
 impl core::ops::Deref for BYTE4_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -215,12 +215,12 @@ impl<'a> BYTE4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `byte5` reader - Updated Byte 5"]
-pub struct BYTE5_R(crate::FieldReader<bool, bool>);
+pub struct BYTE5_R(crate::FieldReader<bool>);
 impl BYTE5_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -228,7 +228,7 @@ impl BYTE5_R {
     }
 }
 impl core::ops::Deref for BYTE5_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -252,12 +252,12 @@ impl<'a> BYTE5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `byte6` reader - Updated Byte 6"]
-pub struct BYTE6_R(crate::FieldReader<bool, bool>);
+pub struct BYTE6_R(crate::FieldReader<bool>);
 impl BYTE6_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -265,7 +265,7 @@ impl BYTE6_R {
     }
 }
 impl core::ops::Deref for BYTE6_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -289,12 +289,12 @@ impl<'a> BYTE6_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `byte7` reader - Updated Byte 7"]
-pub struct BYTE7_R(crate::FieldReader<bool, bool>);
+pub struct BYTE7_R(crate::FieldReader<bool>);
 impl BYTE7_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -302,7 +302,7 @@ impl BYTE7_R {
     }
 }
 impl core::ops::Deref for BYTE7_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -326,12 +326,12 @@ impl<'a> BYTE7_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `byte8` reader - Updated Byte 8"]
-pub struct BYTE8_R(crate::FieldReader<bool, bool>);
+pub struct BYTE8_R(crate::FieldReader<bool>);
 impl BYTE8_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -339,7 +339,7 @@ impl BYTE8_R {
     }
 }
 impl core::ops::Deref for BYTE8_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -363,12 +363,12 @@ impl<'a> BYTE8_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `byte9` reader - Updated Byte 9"]
-pub struct BYTE9_R(crate::FieldReader<bool, bool>);
+pub struct BYTE9_R(crate::FieldReader<bool>);
 impl BYTE9_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -376,7 +376,7 @@ impl BYTE9_R {
     }
 }
 impl core::ops::Deref for BYTE9_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -400,12 +400,12 @@ impl<'a> BYTE9_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `byte10` reader - Updated Byte 10"]
-pub struct BYTE10_R(crate::FieldReader<bool, bool>);
+pub struct BYTE10_R(crate::FieldReader<bool>);
 impl BYTE10_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -413,7 +413,7 @@ impl BYTE10_R {
     }
 }
 impl core::ops::Deref for BYTE10_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -437,12 +437,12 @@ impl<'a> BYTE10_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `byte11` reader - Updated Byte 11"]
-pub struct BYTE11_R(crate::FieldReader<bool, bool>);
+pub struct BYTE11_R(crate::FieldReader<bool>);
 impl BYTE11_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -450,7 +450,7 @@ impl BYTE11_R {
     }
 }
 impl core::ops::Deref for BYTE11_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -474,12 +474,12 @@ impl<'a> BYTE11_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `byte12` reader - Updated Byte 12"]
-pub struct BYTE12_R(crate::FieldReader<bool, bool>);
+pub struct BYTE12_R(crate::FieldReader<bool>);
 impl BYTE12_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -487,7 +487,7 @@ impl BYTE12_R {
     }
 }
 impl core::ops::Deref for BYTE12_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -511,12 +511,12 @@ impl<'a> BYTE12_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `byte13` reader - Updated Byte 13"]
-pub struct BYTE13_R(crate::FieldReader<bool, bool>);
+pub struct BYTE13_R(crate::FieldReader<bool>);
 impl BYTE13_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -524,7 +524,7 @@ impl BYTE13_R {
     }
 }
 impl core::ops::Deref for BYTE13_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -548,12 +548,12 @@ impl<'a> BYTE13_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `byte14` reader - Updated Byte 14"]
-pub struct BYTE14_R(crate::FieldReader<bool, bool>);
+pub struct BYTE14_R(crate::FieldReader<bool>);
 impl BYTE14_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -561,7 +561,7 @@ impl BYTE14_R {
     }
 }
 impl core::ops::Deref for BYTE14_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -585,12 +585,12 @@ impl<'a> BYTE14_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `byte15` reader - Updated Byte 15"]
-pub struct BYTE15_R(crate::FieldReader<bool, bool>);
+pub struct BYTE15_R(crate::FieldReader<bool>);
 impl BYTE15_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -598,7 +598,7 @@ impl BYTE15_R {
     }
 }
 impl core::ops::Deref for BYTE15_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -622,12 +622,12 @@ impl<'a> BYTE15_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
 #[doc = "Field `byte16` reader - Updated Byte 16"]
-pub struct BYTE16_R(crate::FieldReader<bool, bool>);
+pub struct BYTE16_R(crate::FieldReader<bool>);
 impl BYTE16_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -635,7 +635,7 @@ impl BYTE16_R {
     }
 }
 impl core::ops::Deref for BYTE16_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -659,12 +659,12 @@ impl<'a> BYTE16_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
 #[doc = "Field `byte17` reader - Updated Byte 17"]
-pub struct BYTE17_R(crate::FieldReader<bool, bool>);
+pub struct BYTE17_R(crate::FieldReader<bool>);
 impl BYTE17_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -672,7 +672,7 @@ impl BYTE17_R {
     }
 }
 impl core::ops::Deref for BYTE17_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -696,12 +696,12 @@ impl<'a> BYTE17_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
 #[doc = "Field `byte18` reader - Updated Byte 18"]
-pub struct BYTE18_R(crate::FieldReader<bool, bool>);
+pub struct BYTE18_R(crate::FieldReader<bool>);
 impl BYTE18_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -709,7 +709,7 @@ impl BYTE18_R {
     }
 }
 impl core::ops::Deref for BYTE18_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -733,12 +733,12 @@ impl<'a> BYTE18_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
 #[doc = "Field `byte19` reader - Updated Byte 19"]
-pub struct BYTE19_R(crate::FieldReader<bool, bool>);
+pub struct BYTE19_R(crate::FieldReader<bool>);
 impl BYTE19_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -746,7 +746,7 @@ impl BYTE19_R {
     }
 }
 impl core::ops::Deref for BYTE19_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -770,12 +770,12 @@ impl<'a> BYTE19_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
 #[doc = "Field `byte20` reader - Updated Byte 20"]
-pub struct BYTE20_R(crate::FieldReader<bool, bool>);
+pub struct BYTE20_R(crate::FieldReader<bool>);
 impl BYTE20_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -783,7 +783,7 @@ impl BYTE20_R {
     }
 }
 impl core::ops::Deref for BYTE20_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -807,12 +807,12 @@ impl<'a> BYTE20_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
 #[doc = "Field `byte21` reader - Updated Byte 21"]
-pub struct BYTE21_R(crate::FieldReader<bool, bool>);
+pub struct BYTE21_R(crate::FieldReader<bool>);
 impl BYTE21_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -820,7 +820,7 @@ impl BYTE21_R {
     }
 }
 impl core::ops::Deref for BYTE21_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -844,12 +844,12 @@ impl<'a> BYTE21_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
 #[doc = "Field `byte22` reader - Updated Byte 22"]
-pub struct BYTE22_R(crate::FieldReader<bool, bool>);
+pub struct BYTE22_R(crate::FieldReader<bool>);
 impl BYTE22_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -857,7 +857,7 @@ impl BYTE22_R {
     }
 }
 impl core::ops::Deref for BYTE22_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -881,12 +881,12 @@ impl<'a> BYTE22_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
 #[doc = "Field `byte23` reader - Updated Byte 23"]
-pub struct BYTE23_R(crate::FieldReader<bool, bool>);
+pub struct BYTE23_R(crate::FieldReader<bool>);
 impl BYTE23_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -894,7 +894,7 @@ impl BYTE23_R {
     }
 }
 impl core::ops::Deref for BYTE23_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -918,12 +918,12 @@ impl<'a> BYTE23_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
 #[doc = "Field `byte24` reader - Updated Byte 24"]
-pub struct BYTE24_R(crate::FieldReader<bool, bool>);
+pub struct BYTE24_R(crate::FieldReader<bool>);
 impl BYTE24_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -931,7 +931,7 @@ impl BYTE24_R {
     }
 }
 impl core::ops::Deref for BYTE24_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -955,12 +955,12 @@ impl<'a> BYTE24_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
 #[doc = "Field `byte25` reader - Updated Byte 25"]
-pub struct BYTE25_R(crate::FieldReader<bool, bool>);
+pub struct BYTE25_R(crate::FieldReader<bool>);
 impl BYTE25_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -968,7 +968,7 @@ impl BYTE25_R {
     }
 }
 impl core::ops::Deref for BYTE25_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -992,12 +992,12 @@ impl<'a> BYTE25_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
 #[doc = "Field `byte26` reader - Updated Byte 26"]
-pub struct BYTE26_R(crate::FieldReader<bool, bool>);
+pub struct BYTE26_R(crate::FieldReader<bool>);
 impl BYTE26_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -1005,7 +1005,7 @@ impl BYTE26_R {
     }
 }
 impl core::ops::Deref for BYTE26_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -1029,12 +1029,12 @@ impl<'a> BYTE26_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
 #[doc = "Field `byte27` reader - Updated Byte 27"]
-pub struct BYTE27_R(crate::FieldReader<bool, bool>);
+pub struct BYTE27_R(crate::FieldReader<bool>);
 impl BYTE27_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -1042,7 +1042,7 @@ impl BYTE27_R {
     }
 }
 impl core::ops::Deref for BYTE27_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -1066,12 +1066,12 @@ impl<'a> BYTE27_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
 #[doc = "Field `byte28` reader - Updated Byte 28"]
-pub struct BYTE28_R(crate::FieldReader<bool, bool>);
+pub struct BYTE28_R(crate::FieldReader<bool>);
 impl BYTE28_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -1079,7 +1079,7 @@ impl BYTE28_R {
     }
 }
 impl core::ops::Deref for BYTE28_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -1103,12 +1103,12 @@ impl<'a> BYTE28_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
 #[doc = "Field `byte29` reader - Updated Byte 29"]
-pub struct BYTE29_R(crate::FieldReader<bool, bool>);
+pub struct BYTE29_R(crate::FieldReader<bool>);
 impl BYTE29_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -1116,7 +1116,7 @@ impl BYTE29_R {
     }
 }
 impl core::ops::Deref for BYTE29_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -1140,12 +1140,12 @@ impl<'a> BYTE29_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
 #[doc = "Field `byte30` reader - Updated Byte 30"]
-pub struct BYTE30_R(crate::FieldReader<bool, bool>);
+pub struct BYTE30_R(crate::FieldReader<bool>);
 impl BYTE30_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -1153,7 +1153,7 @@ impl BYTE30_R {
     }
 }
 impl core::ops::Deref for BYTE30_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -1177,12 +1177,12 @@ impl<'a> BYTE30_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
 #[doc = "Field `byte31` reader - Updated Byte 31"]
-pub struct BYTE31_R(crate::FieldReader<bool, bool>);
+pub struct BYTE31_R(crate::FieldReader<bool>);
 impl BYTE31_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -1190,7 +1190,7 @@ impl BYTE31_R {
     }
 }
 impl core::ops::Deref for BYTE31_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -1214,7 +1214,7 @@ impl<'a> BYTE31_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -1222,162 +1222,162 @@ impl R {
     #[doc = "Bit 0 - Updated Byte 0"]
     #[inline(always)]
     pub fn byte0(&self) -> BYTE0_R {
-        BYTE0_R::new((self.bits & 0x01) != 0)
+        BYTE0_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - Updated Byte 1"]
     #[inline(always)]
     pub fn byte1(&self) -> BYTE1_R {
-        BYTE1_R::new(((self.bits >> 1) & 0x01) != 0)
+        BYTE1_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - Updated Byte 2"]
     #[inline(always)]
     pub fn byte2(&self) -> BYTE2_R {
-        BYTE2_R::new(((self.bits >> 2) & 0x01) != 0)
+        BYTE2_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - Updated Byte 3"]
     #[inline(always)]
     pub fn byte3(&self) -> BYTE3_R {
-        BYTE3_R::new(((self.bits >> 3) & 0x01) != 0)
+        BYTE3_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - Updated Byte 4"]
     #[inline(always)]
     pub fn byte4(&self) -> BYTE4_R {
-        BYTE4_R::new(((self.bits >> 4) & 0x01) != 0)
+        BYTE4_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - Updated Byte 5"]
     #[inline(always)]
     pub fn byte5(&self) -> BYTE5_R {
-        BYTE5_R::new(((self.bits >> 5) & 0x01) != 0)
+        BYTE5_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - Updated Byte 6"]
     #[inline(always)]
     pub fn byte6(&self) -> BYTE6_R {
-        BYTE6_R::new(((self.bits >> 6) & 0x01) != 0)
+        BYTE6_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - Updated Byte 7"]
     #[inline(always)]
     pub fn byte7(&self) -> BYTE7_R {
-        BYTE7_R::new(((self.bits >> 7) & 0x01) != 0)
+        BYTE7_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - Updated Byte 8"]
     #[inline(always)]
     pub fn byte8(&self) -> BYTE8_R {
-        BYTE8_R::new(((self.bits >> 8) & 0x01) != 0)
+        BYTE8_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - Updated Byte 9"]
     #[inline(always)]
     pub fn byte9(&self) -> BYTE9_R {
-        BYTE9_R::new(((self.bits >> 9) & 0x01) != 0)
+        BYTE9_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - Updated Byte 10"]
     #[inline(always)]
     pub fn byte10(&self) -> BYTE10_R {
-        BYTE10_R::new(((self.bits >> 10) & 0x01) != 0)
+        BYTE10_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - Updated Byte 11"]
     #[inline(always)]
     pub fn byte11(&self) -> BYTE11_R {
-        BYTE11_R::new(((self.bits >> 11) & 0x01) != 0)
+        BYTE11_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - Updated Byte 12"]
     #[inline(always)]
     pub fn byte12(&self) -> BYTE12_R {
-        BYTE12_R::new(((self.bits >> 12) & 0x01) != 0)
+        BYTE12_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - Updated Byte 13"]
     #[inline(always)]
     pub fn byte13(&self) -> BYTE13_R {
-        BYTE13_R::new(((self.bits >> 13) & 0x01) != 0)
+        BYTE13_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - Updated Byte 14"]
     #[inline(always)]
     pub fn byte14(&self) -> BYTE14_R {
-        BYTE14_R::new(((self.bits >> 14) & 0x01) != 0)
+        BYTE14_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - Updated Byte 15"]
     #[inline(always)]
     pub fn byte15(&self) -> BYTE15_R {
-        BYTE15_R::new(((self.bits >> 15) & 0x01) != 0)
+        BYTE15_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 16 - Updated Byte 16"]
     #[inline(always)]
     pub fn byte16(&self) -> BYTE16_R {
-        BYTE16_R::new(((self.bits >> 16) & 0x01) != 0)
+        BYTE16_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - Updated Byte 17"]
     #[inline(always)]
     pub fn byte17(&self) -> BYTE17_R {
-        BYTE17_R::new(((self.bits >> 17) & 0x01) != 0)
+        BYTE17_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 18 - Updated Byte 18"]
     #[inline(always)]
     pub fn byte18(&self) -> BYTE18_R {
-        BYTE18_R::new(((self.bits >> 18) & 0x01) != 0)
+        BYTE18_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - Updated Byte 19"]
     #[inline(always)]
     pub fn byte19(&self) -> BYTE19_R {
-        BYTE19_R::new(((self.bits >> 19) & 0x01) != 0)
+        BYTE19_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 20 - Updated Byte 20"]
     #[inline(always)]
     pub fn byte20(&self) -> BYTE20_R {
-        BYTE20_R::new(((self.bits >> 20) & 0x01) != 0)
+        BYTE20_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 21 - Updated Byte 21"]
     #[inline(always)]
     pub fn byte21(&self) -> BYTE21_R {
-        BYTE21_R::new(((self.bits >> 21) & 0x01) != 0)
+        BYTE21_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 22 - Updated Byte 22"]
     #[inline(always)]
     pub fn byte22(&self) -> BYTE22_R {
-        BYTE22_R::new(((self.bits >> 22) & 0x01) != 0)
+        BYTE22_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 23 - Updated Byte 23"]
     #[inline(always)]
     pub fn byte23(&self) -> BYTE23_R {
-        BYTE23_R::new(((self.bits >> 23) & 0x01) != 0)
+        BYTE23_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 24 - Updated Byte 24"]
     #[inline(always)]
     pub fn byte24(&self) -> BYTE24_R {
-        BYTE24_R::new(((self.bits >> 24) & 0x01) != 0)
+        BYTE24_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 25 - Updated Byte 25"]
     #[inline(always)]
     pub fn byte25(&self) -> BYTE25_R {
-        BYTE25_R::new(((self.bits >> 25) & 0x01) != 0)
+        BYTE25_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 26 - Updated Byte 26"]
     #[inline(always)]
     pub fn byte26(&self) -> BYTE26_R {
-        BYTE26_R::new(((self.bits >> 26) & 0x01) != 0)
+        BYTE26_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 27 - Updated Byte 27"]
     #[inline(always)]
     pub fn byte27(&self) -> BYTE27_R {
-        BYTE27_R::new(((self.bits >> 27) & 0x01) != 0)
+        BYTE27_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - Updated Byte 28"]
     #[inline(always)]
     pub fn byte28(&self) -> BYTE28_R {
-        BYTE28_R::new(((self.bits >> 28) & 0x01) != 0)
+        BYTE28_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 29 - Updated Byte 29"]
     #[inline(always)]
     pub fn byte29(&self) -> BYTE29_R {
-        BYTE29_R::new(((self.bits >> 29) & 0x01) != 0)
+        BYTE29_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 30 - Updated Byte 30"]
     #[inline(always)]
     pub fn byte30(&self) -> BYTE30_R {
-        BYTE30_R::new(((self.bits >> 30) & 0x01) != 0)
+        BYTE30_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 31 - Updated Byte 31"]
     #[inline(always)]
     pub fn byte31(&self) -> BYTE31_R {
-        BYTE31_R::new(((self.bits >> 31) & 0x01) != 0)
+        BYTE31_R::new(((self.bits >> 31) & 1) != 0)
     }
 }
 impl W {
