@@ -35,7 +35,7 @@ impl From<crate::W<CTRL_SPEC>> for W {
     }
 }
 #[doc = "Field `start` reader - Start MAA Calculation"]
-pub struct START_R(crate::FieldReader<bool, bool>);
+pub struct START_R(crate::FieldReader<bool>);
 impl START_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl START_R {
     }
 }
 impl core::ops::Deref for START_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,7 +67,7 @@ impl<'a> START_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -95,7 +95,7 @@ impl From<OPSEL_A> for u8 {
     }
 }
 #[doc = "Field `opsel` reader - Select Operation Type"]
-pub struct OPSEL_R(crate::FieldReader<u8, OPSEL_A>);
+pub struct OPSEL_R(crate::FieldReader<u8>);
 impl OPSEL_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -146,7 +146,7 @@ impl OPSEL_R {
     }
 }
 impl core::ops::Deref for OPSEL_R {
-    type Target = crate::FieldReader<u8, OPSEL_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -195,12 +195,12 @@ impl<'a> OPSEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 1)) | ((value as u32 & 0x07) << 1);
+        self.w.bits = (self.w.bits & !(7 << 1)) | ((value as u32 & 7) << 1);
         self.w
     }
 }
 #[doc = "Field `ocalc` reader - Optimized Calculation Control"]
-pub struct OCALC_R(crate::FieldReader<bool, bool>);
+pub struct OCALC_R(crate::FieldReader<bool>);
 impl OCALC_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -208,7 +208,7 @@ impl OCALC_R {
     }
 }
 impl core::ops::Deref for OCALC_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -232,12 +232,12 @@ impl<'a> OCALC_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `if_done` reader - Interrupt Flag - Calculation Done"]
-pub struct IF_DONE_R(crate::FieldReader<bool, bool>);
+pub struct IF_DONE_R(crate::FieldReader<bool>);
 impl IF_DONE_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -245,7 +245,7 @@ impl IF_DONE_R {
     }
 }
 impl core::ops::Deref for IF_DONE_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -269,12 +269,12 @@ impl<'a> IF_DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `inten` reader - MAA Interrupt Enable"]
-pub struct INTEN_R(crate::FieldReader<bool, bool>);
+pub struct INTEN_R(crate::FieldReader<bool>);
 impl INTEN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -282,7 +282,7 @@ impl INTEN_R {
     }
 }
 impl core::ops::Deref for INTEN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -306,12 +306,12 @@ impl<'a> INTEN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `if_error` reader - Interrupt Flag - Error"]
-pub struct IF_ERROR_R(crate::FieldReader<bool, bool>);
+pub struct IF_ERROR_R(crate::FieldReader<bool>);
 impl IF_ERROR_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -319,7 +319,7 @@ impl IF_ERROR_R {
     }
 }
 impl core::ops::Deref for IF_ERROR_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -343,12 +343,12 @@ impl<'a> IF_ERROR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `ofs_a` reader - Operand A Memory Offset Select"]
-pub struct OFS_A_R(crate::FieldReader<u8, u8>);
+pub struct OFS_A_R(crate::FieldReader<u8>);
 impl OFS_A_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -356,7 +356,7 @@ impl OFS_A_R {
     }
 }
 impl core::ops::Deref for OFS_A_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -370,12 +370,12 @@ impl<'a> OFS_A_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 8)) | ((value as u32 & 0x03) << 8);
+        self.w.bits = (self.w.bits & !(3 << 8)) | ((value as u32 & 3) << 8);
         self.w
     }
 }
 #[doc = "Field `ofs_b` reader - Operand B Memory Offset Select"]
-pub struct OFS_B_R(crate::FieldReader<u8, u8>);
+pub struct OFS_B_R(crate::FieldReader<u8>);
 impl OFS_B_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -383,7 +383,7 @@ impl OFS_B_R {
     }
 }
 impl core::ops::Deref for OFS_B_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -397,12 +397,12 @@ impl<'a> OFS_B_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 10)) | ((value as u32 & 0x03) << 10);
+        self.w.bits = (self.w.bits & !(3 << 10)) | ((value as u32 & 3) << 10);
         self.w
     }
 }
 #[doc = "Field `ofs_exp` reader - Exponent Memory Offset Select"]
-pub struct OFS_EXP_R(crate::FieldReader<u8, u8>);
+pub struct OFS_EXP_R(crate::FieldReader<u8>);
 impl OFS_EXP_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -410,7 +410,7 @@ impl OFS_EXP_R {
     }
 }
 impl core::ops::Deref for OFS_EXP_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -424,12 +424,12 @@ impl<'a> OFS_EXP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 12)) | ((value as u32 & 0x03) << 12);
+        self.w.bits = (self.w.bits & !(3 << 12)) | ((value as u32 & 3) << 12);
         self.w
     }
 }
 #[doc = "Field `ofs_mod` reader - Modulus Memory Select"]
-pub struct OFS_MOD_R(crate::FieldReader<u8, u8>);
+pub struct OFS_MOD_R(crate::FieldReader<u8>);
 impl OFS_MOD_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -437,7 +437,7 @@ impl OFS_MOD_R {
     }
 }
 impl core::ops::Deref for OFS_MOD_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -451,12 +451,12 @@ impl<'a> OFS_MOD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 14)) | ((value as u32 & 0x03) << 14);
+        self.w.bits = (self.w.bits & !(3 << 14)) | ((value as u32 & 3) << 14);
         self.w
     }
 }
 #[doc = "Field `seg_a` reader - Operand A Memory Segment Select"]
-pub struct SEG_A_R(crate::FieldReader<u8, u8>);
+pub struct SEG_A_R(crate::FieldReader<u8>);
 impl SEG_A_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -464,7 +464,7 @@ impl SEG_A_R {
     }
 }
 impl core::ops::Deref for SEG_A_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -483,7 +483,7 @@ impl<'a> SEG_A_W<'a> {
     }
 }
 #[doc = "Field `seg_b` reader - Operand B Memory Segment Select"]
-pub struct SEG_B_R(crate::FieldReader<u8, u8>);
+pub struct SEG_B_R(crate::FieldReader<u8>);
 impl SEG_B_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -491,7 +491,7 @@ impl SEG_B_R {
     }
 }
 impl core::ops::Deref for SEG_B_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -510,7 +510,7 @@ impl<'a> SEG_B_W<'a> {
     }
 }
 #[doc = "Field `seg_res` reader - Result Memory Segment Select"]
-pub struct SEG_RES_R(crate::FieldReader<u8, u8>);
+pub struct SEG_RES_R(crate::FieldReader<u8>);
 impl SEG_RES_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -518,7 +518,7 @@ impl SEG_RES_R {
     }
 }
 impl core::ops::Deref for SEG_RES_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -537,7 +537,7 @@ impl<'a> SEG_RES_W<'a> {
     }
 }
 #[doc = "Field `seg_tmp` reader - Temporary Memory Segment Select"]
-pub struct SEG_TMP_R(crate::FieldReader<u8, u8>);
+pub struct SEG_TMP_R(crate::FieldReader<u8>);
 impl SEG_TMP_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -545,7 +545,7 @@ impl SEG_TMP_R {
     }
 }
 impl core::ops::Deref for SEG_TMP_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -567,52 +567,52 @@ impl R {
     #[doc = "Bit 0 - Start MAA Calculation"]
     #[inline(always)]
     pub fn start(&self) -> START_R {
-        START_R::new((self.bits & 0x01) != 0)
+        START_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bits 1:3 - Select Operation Type"]
     #[inline(always)]
     pub fn opsel(&self) -> OPSEL_R {
-        OPSEL_R::new(((self.bits >> 1) & 0x07) as u8)
+        OPSEL_R::new(((self.bits >> 1) & 7) as u8)
     }
     #[doc = "Bit 4 - Optimized Calculation Control"]
     #[inline(always)]
     pub fn ocalc(&self) -> OCALC_R {
-        OCALC_R::new(((self.bits >> 4) & 0x01) != 0)
+        OCALC_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - Interrupt Flag - Calculation Done"]
     #[inline(always)]
     pub fn if_done(&self) -> IF_DONE_R {
-        IF_DONE_R::new(((self.bits >> 5) & 0x01) != 0)
+        IF_DONE_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - MAA Interrupt Enable"]
     #[inline(always)]
     pub fn inten(&self) -> INTEN_R {
-        INTEN_R::new(((self.bits >> 6) & 0x01) != 0)
+        INTEN_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - Interrupt Flag - Error"]
     #[inline(always)]
     pub fn if_error(&self) -> IF_ERROR_R {
-        IF_ERROR_R::new(((self.bits >> 7) & 0x01) != 0)
+        IF_ERROR_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bits 8:9 - Operand A Memory Offset Select"]
     #[inline(always)]
     pub fn ofs_a(&self) -> OFS_A_R {
-        OFS_A_R::new(((self.bits >> 8) & 0x03) as u8)
+        OFS_A_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 10:11 - Operand B Memory Offset Select"]
     #[inline(always)]
     pub fn ofs_b(&self) -> OFS_B_R {
-        OFS_B_R::new(((self.bits >> 10) & 0x03) as u8)
+        OFS_B_R::new(((self.bits >> 10) & 3) as u8)
     }
     #[doc = "Bits 12:13 - Exponent Memory Offset Select"]
     #[inline(always)]
     pub fn ofs_exp(&self) -> OFS_EXP_R {
-        OFS_EXP_R::new(((self.bits >> 12) & 0x03) as u8)
+        OFS_EXP_R::new(((self.bits >> 12) & 3) as u8)
     }
     #[doc = "Bits 14:15 - Modulus Memory Select"]
     #[inline(always)]
     pub fn ofs_mod(&self) -> OFS_MOD_R {
-        OFS_MOD_R::new(((self.bits >> 14) & 0x03) as u8)
+        OFS_MOD_R::new(((self.bits >> 14) & 3) as u8)
     }
     #[doc = "Bits 16:19 - Operand A Memory Segment Select"]
     #[inline(always)]
