@@ -35,7 +35,7 @@ impl From<crate::W<RESYNC_SPEC>> for W {
     }
 }
 #[doc = "Field `pt0` reader - Resync control for PT0"]
-pub struct PT0_R(crate::FieldReader<bool, bool>);
+pub struct PT0_R(crate::FieldReader<bool>);
 impl PT0_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl PT0_R {
     }
 }
 impl core::ops::Deref for PT0_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,12 +67,12 @@ impl<'a> PT0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `pt1` reader - Resync control for PT1"]
-pub struct PT1_R(crate::FieldReader<bool, bool>);
+pub struct PT1_R(crate::FieldReader<bool>);
 impl PT1_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -80,7 +80,7 @@ impl PT1_R {
     }
 }
 impl core::ops::Deref for PT1_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -104,12 +104,12 @@ impl<'a> PT1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `pt2` reader - Resync control for PT2"]
-pub struct PT2_R(crate::FieldReader<bool, bool>);
+pub struct PT2_R(crate::FieldReader<bool>);
 impl PT2_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -117,7 +117,7 @@ impl PT2_R {
     }
 }
 impl core::ops::Deref for PT2_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -141,12 +141,12 @@ impl<'a> PT2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `pt3` reader - Resync control for PT3"]
-pub struct PT3_R(crate::FieldReader<bool, bool>);
+pub struct PT3_R(crate::FieldReader<bool>);
 impl PT3_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -154,7 +154,7 @@ impl PT3_R {
     }
 }
 impl core::ops::Deref for PT3_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -178,12 +178,12 @@ impl<'a> PT3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `pt4` reader - Resync control for PT4"]
-pub struct PT4_R(crate::FieldReader<bool, bool>);
+pub struct PT4_R(crate::FieldReader<bool>);
 impl PT4_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -191,7 +191,7 @@ impl PT4_R {
     }
 }
 impl core::ops::Deref for PT4_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -215,12 +215,12 @@ impl<'a> PT4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `pt5` reader - Resync control for PT5"]
-pub struct PT5_R(crate::FieldReader<bool, bool>);
+pub struct PT5_R(crate::FieldReader<bool>);
 impl PT5_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -228,7 +228,7 @@ impl PT5_R {
     }
 }
 impl core::ops::Deref for PT5_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -252,12 +252,12 @@ impl<'a> PT5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `pt6` reader - Resync control for PT6"]
-pub struct PT6_R(crate::FieldReader<bool, bool>);
+pub struct PT6_R(crate::FieldReader<bool>);
 impl PT6_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -265,7 +265,7 @@ impl PT6_R {
     }
 }
 impl core::ops::Deref for PT6_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -289,12 +289,12 @@ impl<'a> PT6_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `pt7` reader - Resync control for PT7"]
-pub struct PT7_R(crate::FieldReader<bool, bool>);
+pub struct PT7_R(crate::FieldReader<bool>);
 impl PT7_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -302,7 +302,7 @@ impl PT7_R {
     }
 }
 impl core::ops::Deref for PT7_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -326,12 +326,12 @@ impl<'a> PT7_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `pt8` reader - Resync control for PT8"]
-pub struct PT8_R(crate::FieldReader<bool, bool>);
+pub struct PT8_R(crate::FieldReader<bool>);
 impl PT8_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -339,7 +339,7 @@ impl PT8_R {
     }
 }
 impl core::ops::Deref for PT8_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -363,12 +363,12 @@ impl<'a> PT8_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `pt9` reader - Resync control for PT9"]
-pub struct PT9_R(crate::FieldReader<bool, bool>);
+pub struct PT9_R(crate::FieldReader<bool>);
 impl PT9_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -376,7 +376,7 @@ impl PT9_R {
     }
 }
 impl core::ops::Deref for PT9_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -400,12 +400,12 @@ impl<'a> PT9_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `pt10` reader - Resync control for PT10"]
-pub struct PT10_R(crate::FieldReader<bool, bool>);
+pub struct PT10_R(crate::FieldReader<bool>);
 impl PT10_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -413,7 +413,7 @@ impl PT10_R {
     }
 }
 impl core::ops::Deref for PT10_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -437,12 +437,12 @@ impl<'a> PT10_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `pt11` reader - Resync control for PT11"]
-pub struct PT11_R(crate::FieldReader<bool, bool>);
+pub struct PT11_R(crate::FieldReader<bool>);
 impl PT11_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -450,7 +450,7 @@ impl PT11_R {
     }
 }
 impl core::ops::Deref for PT11_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -474,12 +474,12 @@ impl<'a> PT11_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `pt12` reader - Resync control for PT12"]
-pub struct PT12_R(crate::FieldReader<bool, bool>);
+pub struct PT12_R(crate::FieldReader<bool>);
 impl PT12_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -487,7 +487,7 @@ impl PT12_R {
     }
 }
 impl core::ops::Deref for PT12_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -511,12 +511,12 @@ impl<'a> PT12_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `pt13` reader - Resync control for PT13"]
-pub struct PT13_R(crate::FieldReader<bool, bool>);
+pub struct PT13_R(crate::FieldReader<bool>);
 impl PT13_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -524,7 +524,7 @@ impl PT13_R {
     }
 }
 impl core::ops::Deref for PT13_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -548,12 +548,12 @@ impl<'a> PT13_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `pt14` reader - Resync control for PT14"]
-pub struct PT14_R(crate::FieldReader<bool, bool>);
+pub struct PT14_R(crate::FieldReader<bool>);
 impl PT14_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -561,7 +561,7 @@ impl PT14_R {
     }
 }
 impl core::ops::Deref for PT14_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -585,12 +585,12 @@ impl<'a> PT14_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `pt15` reader - Resync control for PT15"]
-pub struct PT15_R(crate::FieldReader<bool, bool>);
+pub struct PT15_R(crate::FieldReader<bool>);
 impl PT15_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -598,7 +598,7 @@ impl PT15_R {
     }
 }
 impl core::ops::Deref for PT15_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -622,7 +622,7 @@ impl<'a> PT15_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -630,82 +630,82 @@ impl R {
     #[doc = "Bit 0 - Resync control for PT0"]
     #[inline(always)]
     pub fn pt0(&self) -> PT0_R {
-        PT0_R::new((self.bits & 0x01) != 0)
+        PT0_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - Resync control for PT1"]
     #[inline(always)]
     pub fn pt1(&self) -> PT1_R {
-        PT1_R::new(((self.bits >> 1) & 0x01) != 0)
+        PT1_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - Resync control for PT2"]
     #[inline(always)]
     pub fn pt2(&self) -> PT2_R {
-        PT2_R::new(((self.bits >> 2) & 0x01) != 0)
+        PT2_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - Resync control for PT3"]
     #[inline(always)]
     pub fn pt3(&self) -> PT3_R {
-        PT3_R::new(((self.bits >> 3) & 0x01) != 0)
+        PT3_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - Resync control for PT4"]
     #[inline(always)]
     pub fn pt4(&self) -> PT4_R {
-        PT4_R::new(((self.bits >> 4) & 0x01) != 0)
+        PT4_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - Resync control for PT5"]
     #[inline(always)]
     pub fn pt5(&self) -> PT5_R {
-        PT5_R::new(((self.bits >> 5) & 0x01) != 0)
+        PT5_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - Resync control for PT6"]
     #[inline(always)]
     pub fn pt6(&self) -> PT6_R {
-        PT6_R::new(((self.bits >> 6) & 0x01) != 0)
+        PT6_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - Resync control for PT7"]
     #[inline(always)]
     pub fn pt7(&self) -> PT7_R {
-        PT7_R::new(((self.bits >> 7) & 0x01) != 0)
+        PT7_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - Resync control for PT8"]
     #[inline(always)]
     pub fn pt8(&self) -> PT8_R {
-        PT8_R::new(((self.bits >> 8) & 0x01) != 0)
+        PT8_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - Resync control for PT9"]
     #[inline(always)]
     pub fn pt9(&self) -> PT9_R {
-        PT9_R::new(((self.bits >> 9) & 0x01) != 0)
+        PT9_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - Resync control for PT10"]
     #[inline(always)]
     pub fn pt10(&self) -> PT10_R {
-        PT10_R::new(((self.bits >> 10) & 0x01) != 0)
+        PT10_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - Resync control for PT11"]
     #[inline(always)]
     pub fn pt11(&self) -> PT11_R {
-        PT11_R::new(((self.bits >> 11) & 0x01) != 0)
+        PT11_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - Resync control for PT12"]
     #[inline(always)]
     pub fn pt12(&self) -> PT12_R {
-        PT12_R::new(((self.bits >> 12) & 0x01) != 0)
+        PT12_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - Resync control for PT13"]
     #[inline(always)]
     pub fn pt13(&self) -> PT13_R {
-        PT13_R::new(((self.bits >> 13) & 0x01) != 0)
+        PT13_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - Resync control for PT14"]
     #[inline(always)]
     pub fn pt14(&self) -> PT14_R {
-        PT14_R::new(((self.bits >> 14) & 0x01) != 0)
+        PT14_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - Resync control for PT15"]
     #[inline(always)]
     pub fn pt15(&self) -> PT15_R {
-        PT15_R::new(((self.bits >> 15) & 0x01) != 0)
+        PT15_R::new(((self.bits >> 15) & 1) != 0)
     }
 }
 impl W {
