@@ -35,7 +35,7 @@ impl From<crate::W<PERIPHERAL_RESET_SPEC>> for W {
     }
 }
 #[doc = "Field `ssb` reader - Reset SSB"]
-pub struct SSB_R(crate::FieldReader<bool, bool>);
+pub struct SSB_R(crate::FieldReader<bool>);
 impl SSB_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl SSB_R {
     }
 }
 impl core::ops::Deref for SSB_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,12 +67,12 @@ impl<'a> SSB_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `spix` reader - Reset SPI XIP"]
-pub struct SPIX_R(crate::FieldReader<bool, bool>);
+pub struct SPIX_R(crate::FieldReader<bool>);
 impl SPIX_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -80,7 +80,7 @@ impl SPIX_R {
     }
 }
 impl core::ops::Deref for SPIX_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -104,12 +104,12 @@ impl<'a> SPIX_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `pmu` reader - Reset PMU"]
-pub struct PMU_R(crate::FieldReader<bool, bool>);
+pub struct PMU_R(crate::FieldReader<bool>);
 impl PMU_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -117,7 +117,7 @@ impl PMU_R {
     }
 }
 impl core::ops::Deref for PMU_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -141,12 +141,12 @@ impl<'a> PMU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `usb` reader - Reset USB"]
-pub struct USB_R(crate::FieldReader<bool, bool>);
+pub struct USB_R(crate::FieldReader<bool>);
 impl USB_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -154,7 +154,7 @@ impl USB_R {
     }
 }
 impl core::ops::Deref for USB_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -178,12 +178,12 @@ impl<'a> USB_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `crc` reader - Reset CRC"]
-pub struct CRC_R(crate::FieldReader<bool, bool>);
+pub struct CRC_R(crate::FieldReader<bool>);
 impl CRC_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -191,7 +191,7 @@ impl CRC_R {
     }
 }
 impl core::ops::Deref for CRC_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -215,12 +215,12 @@ impl<'a> CRC_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `tpu` reader - Reset TPU"]
-pub struct TPU_R(crate::FieldReader<bool, bool>);
+pub struct TPU_R(crate::FieldReader<bool>);
 impl TPU_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -228,7 +228,7 @@ impl TPU_R {
     }
 }
 impl core::ops::Deref for TPU_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -252,12 +252,12 @@ impl<'a> TPU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `watchdog0` reader - Reset Watchdog Timer 0"]
-pub struct WATCHDOG0_R(crate::FieldReader<bool, bool>);
+pub struct WATCHDOG0_R(crate::FieldReader<bool>);
 impl WATCHDOG0_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -265,7 +265,7 @@ impl WATCHDOG0_R {
     }
 }
 impl core::ops::Deref for WATCHDOG0_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -289,12 +289,12 @@ impl<'a> WATCHDOG0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `gpio` reader - Reset GPIO"]
-pub struct GPIO_R(crate::FieldReader<bool, bool>);
+pub struct GPIO_R(crate::FieldReader<bool>);
 impl GPIO_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -302,7 +302,7 @@ impl GPIO_R {
     }
 }
 impl core::ops::Deref for GPIO_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -326,12 +326,12 @@ impl<'a> GPIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `timer0` reader - Reset Timer/Counter Module 0"]
-pub struct TIMER0_R(crate::FieldReader<bool, bool>);
+pub struct TIMER0_R(crate::FieldReader<bool>);
 impl TIMER0_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -339,7 +339,7 @@ impl TIMER0_R {
     }
 }
 impl core::ops::Deref for TIMER0_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -363,12 +363,12 @@ impl<'a> TIMER0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `timer1` reader - Reset Timer/Counter Module 1"]
-pub struct TIMER1_R(crate::FieldReader<bool, bool>);
+pub struct TIMER1_R(crate::FieldReader<bool>);
 impl TIMER1_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -376,7 +376,7 @@ impl TIMER1_R {
     }
 }
 impl core::ops::Deref for TIMER1_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -400,12 +400,12 @@ impl<'a> TIMER1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `timer2` reader - Reset Timer/Counter Module 2"]
-pub struct TIMER2_R(crate::FieldReader<bool, bool>);
+pub struct TIMER2_R(crate::FieldReader<bool>);
 impl TIMER2_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -413,7 +413,7 @@ impl TIMER2_R {
     }
 }
 impl core::ops::Deref for TIMER2_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -437,12 +437,12 @@ impl<'a> TIMER2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `timer3` reader - Reset Timer/Counter Module 3"]
-pub struct TIMER3_R(crate::FieldReader<bool, bool>);
+pub struct TIMER3_R(crate::FieldReader<bool>);
 impl TIMER3_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -450,7 +450,7 @@ impl TIMER3_R {
     }
 }
 impl core::ops::Deref for TIMER3_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -474,12 +474,12 @@ impl<'a> TIMER3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `timer4` reader - Reset Timer/Counter Module 4"]
-pub struct TIMER4_R(crate::FieldReader<bool, bool>);
+pub struct TIMER4_R(crate::FieldReader<bool>);
 impl TIMER4_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -487,7 +487,7 @@ impl TIMER4_R {
     }
 }
 impl core::ops::Deref for TIMER4_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -511,12 +511,12 @@ impl<'a> TIMER4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `timer5` reader - Reset Timer/Counter Module 5"]
-pub struct TIMER5_R(crate::FieldReader<bool, bool>);
+pub struct TIMER5_R(crate::FieldReader<bool>);
 impl TIMER5_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -524,7 +524,7 @@ impl TIMER5_R {
     }
 }
 impl core::ops::Deref for TIMER5_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -548,12 +548,12 @@ impl<'a> TIMER5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `pulse_train` reader - Reset All Pulse Trains"]
-pub struct PULSE_TRAIN_R(crate::FieldReader<bool, bool>);
+pub struct PULSE_TRAIN_R(crate::FieldReader<bool>);
 impl PULSE_TRAIN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -561,7 +561,7 @@ impl PULSE_TRAIN_R {
     }
 }
 impl core::ops::Deref for PULSE_TRAIN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -585,12 +585,12 @@ impl<'a> PULSE_TRAIN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `uart0` reader - Reset UART 0"]
-pub struct UART0_R(crate::FieldReader<bool, bool>);
+pub struct UART0_R(crate::FieldReader<bool>);
 impl UART0_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -598,7 +598,7 @@ impl UART0_R {
     }
 }
 impl core::ops::Deref for UART0_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -622,12 +622,12 @@ impl<'a> UART0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
 #[doc = "Field `uart1` reader - Reset UART 1"]
-pub struct UART1_R(crate::FieldReader<bool, bool>);
+pub struct UART1_R(crate::FieldReader<bool>);
 impl UART1_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -635,7 +635,7 @@ impl UART1_R {
     }
 }
 impl core::ops::Deref for UART1_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -659,12 +659,12 @@ impl<'a> UART1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
 #[doc = "Field `uart2` reader - Reset UART 2"]
-pub struct UART2_R(crate::FieldReader<bool, bool>);
+pub struct UART2_R(crate::FieldReader<bool>);
 impl UART2_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -672,7 +672,7 @@ impl UART2_R {
     }
 }
 impl core::ops::Deref for UART2_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -696,12 +696,12 @@ impl<'a> UART2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
 #[doc = "Field `uart3` reader - Reset UART 3"]
-pub struct UART3_R(crate::FieldReader<bool, bool>);
+pub struct UART3_R(crate::FieldReader<bool>);
 impl UART3_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -709,7 +709,7 @@ impl UART3_R {
     }
 }
 impl core::ops::Deref for UART3_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -733,12 +733,12 @@ impl<'a> UART3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
 #[doc = "Field `i2cm0` reader - Reset I2C Master 0"]
-pub struct I2CM0_R(crate::FieldReader<bool, bool>);
+pub struct I2CM0_R(crate::FieldReader<bool>);
 impl I2CM0_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -746,7 +746,7 @@ impl I2CM0_R {
     }
 }
 impl core::ops::Deref for I2CM0_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -770,12 +770,12 @@ impl<'a> I2CM0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
 #[doc = "Field `i2cm1` reader - Reset I2C Master 1"]
-pub struct I2CM1_R(crate::FieldReader<bool, bool>);
+pub struct I2CM1_R(crate::FieldReader<bool>);
 impl I2CM1_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -783,7 +783,7 @@ impl I2CM1_R {
     }
 }
 impl core::ops::Deref for I2CM1_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -807,12 +807,12 @@ impl<'a> I2CM1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
 #[doc = "Field `i2cm2` reader - Reset I2C Master 2"]
-pub struct I2CM2_R(crate::FieldReader<bool, bool>);
+pub struct I2CM2_R(crate::FieldReader<bool>);
 impl I2CM2_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -820,7 +820,7 @@ impl I2CM2_R {
     }
 }
 impl core::ops::Deref for I2CM2_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -844,12 +844,12 @@ impl<'a> I2CM2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
 #[doc = "Field `i2cs` reader - Reset I2C Slave"]
-pub struct I2CS_R(crate::FieldReader<bool, bool>);
+pub struct I2CS_R(crate::FieldReader<bool>);
 impl I2CS_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -857,7 +857,7 @@ impl I2CS_R {
     }
 }
 impl core::ops::Deref for I2CS_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -881,12 +881,12 @@ impl<'a> I2CS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
 #[doc = "Field `spim0` reader - Reset SPI Master 0"]
-pub struct SPIM0_R(crate::FieldReader<bool, bool>);
+pub struct SPIM0_R(crate::FieldReader<bool>);
 impl SPIM0_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -894,7 +894,7 @@ impl SPIM0_R {
     }
 }
 impl core::ops::Deref for SPIM0_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -918,12 +918,12 @@ impl<'a> SPIM0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
 #[doc = "Field `spim1` reader - Reset SPI Master 1"]
-pub struct SPIM1_R(crate::FieldReader<bool, bool>);
+pub struct SPIM1_R(crate::FieldReader<bool>);
 impl SPIM1_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -931,7 +931,7 @@ impl SPIM1_R {
     }
 }
 impl core::ops::Deref for SPIM1_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -955,12 +955,12 @@ impl<'a> SPIM1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
 #[doc = "Field `spim2` reader - Reset SPI Master 2"]
-pub struct SPIM2_R(crate::FieldReader<bool, bool>);
+pub struct SPIM2_R(crate::FieldReader<bool>);
 impl SPIM2_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -968,7 +968,7 @@ impl SPIM2_R {
     }
 }
 impl core::ops::Deref for SPIM2_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -992,12 +992,12 @@ impl<'a> SPIM2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
 #[doc = "Field `spib` reader - Reset SPI Bridge"]
-pub struct SPIB_R(crate::FieldReader<bool, bool>);
+pub struct SPIB_R(crate::FieldReader<bool>);
 impl SPIB_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -1005,7 +1005,7 @@ impl SPIB_R {
     }
 }
 impl core::ops::Deref for SPIB_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -1029,12 +1029,12 @@ impl<'a> SPIB_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
 #[doc = "Field `owm` reader - Reset 1-Wire Master"]
-pub struct OWM_R(crate::FieldReader<bool, bool>);
+pub struct OWM_R(crate::FieldReader<bool>);
 impl OWM_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -1042,7 +1042,7 @@ impl OWM_R {
     }
 }
 impl core::ops::Deref for OWM_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -1066,12 +1066,12 @@ impl<'a> OWM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
 #[doc = "Field `adc` reader - Reset ADC"]
-pub struct ADC_R(crate::FieldReader<bool, bool>);
+pub struct ADC_R(crate::FieldReader<bool>);
 impl ADC_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -1079,7 +1079,7 @@ impl ADC_R {
     }
 }
 impl core::ops::Deref for ADC_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -1103,7 +1103,7 @@ impl<'a> ADC_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
@@ -1111,147 +1111,147 @@ impl R {
     #[doc = "Bit 0 - Reset SSB"]
     #[inline(always)]
     pub fn ssb(&self) -> SSB_R {
-        SSB_R::new((self.bits & 0x01) != 0)
+        SSB_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - Reset SPI XIP"]
     #[inline(always)]
     pub fn spix(&self) -> SPIX_R {
-        SPIX_R::new(((self.bits >> 1) & 0x01) != 0)
+        SPIX_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - Reset PMU"]
     #[inline(always)]
     pub fn pmu(&self) -> PMU_R {
-        PMU_R::new(((self.bits >> 2) & 0x01) != 0)
+        PMU_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - Reset USB"]
     #[inline(always)]
     pub fn usb(&self) -> USB_R {
-        USB_R::new(((self.bits >> 3) & 0x01) != 0)
+        USB_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - Reset CRC"]
     #[inline(always)]
     pub fn crc(&self) -> CRC_R {
-        CRC_R::new(((self.bits >> 4) & 0x01) != 0)
+        CRC_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - Reset TPU"]
     #[inline(always)]
     pub fn tpu(&self) -> TPU_R {
-        TPU_R::new(((self.bits >> 5) & 0x01) != 0)
+        TPU_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - Reset Watchdog Timer 0"]
     #[inline(always)]
     pub fn watchdog0(&self) -> WATCHDOG0_R {
-        WATCHDOG0_R::new(((self.bits >> 6) & 0x01) != 0)
+        WATCHDOG0_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - Reset GPIO"]
     #[inline(always)]
     pub fn gpio(&self) -> GPIO_R {
-        GPIO_R::new(((self.bits >> 7) & 0x01) != 0)
+        GPIO_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - Reset Timer/Counter Module 0"]
     #[inline(always)]
     pub fn timer0(&self) -> TIMER0_R {
-        TIMER0_R::new(((self.bits >> 8) & 0x01) != 0)
+        TIMER0_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - Reset Timer/Counter Module 1"]
     #[inline(always)]
     pub fn timer1(&self) -> TIMER1_R {
-        TIMER1_R::new(((self.bits >> 9) & 0x01) != 0)
+        TIMER1_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - Reset Timer/Counter Module 2"]
     #[inline(always)]
     pub fn timer2(&self) -> TIMER2_R {
-        TIMER2_R::new(((self.bits >> 10) & 0x01) != 0)
+        TIMER2_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - Reset Timer/Counter Module 3"]
     #[inline(always)]
     pub fn timer3(&self) -> TIMER3_R {
-        TIMER3_R::new(((self.bits >> 11) & 0x01) != 0)
+        TIMER3_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - Reset Timer/Counter Module 4"]
     #[inline(always)]
     pub fn timer4(&self) -> TIMER4_R {
-        TIMER4_R::new(((self.bits >> 12) & 0x01) != 0)
+        TIMER4_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - Reset Timer/Counter Module 5"]
     #[inline(always)]
     pub fn timer5(&self) -> TIMER5_R {
-        TIMER5_R::new(((self.bits >> 13) & 0x01) != 0)
+        TIMER5_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - Reset All Pulse Trains"]
     #[inline(always)]
     pub fn pulse_train(&self) -> PULSE_TRAIN_R {
-        PULSE_TRAIN_R::new(((self.bits >> 14) & 0x01) != 0)
+        PULSE_TRAIN_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - Reset UART 0"]
     #[inline(always)]
     pub fn uart0(&self) -> UART0_R {
-        UART0_R::new(((self.bits >> 15) & 0x01) != 0)
+        UART0_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 16 - Reset UART 1"]
     #[inline(always)]
     pub fn uart1(&self) -> UART1_R {
-        UART1_R::new(((self.bits >> 16) & 0x01) != 0)
+        UART1_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - Reset UART 2"]
     #[inline(always)]
     pub fn uart2(&self) -> UART2_R {
-        UART2_R::new(((self.bits >> 17) & 0x01) != 0)
+        UART2_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 18 - Reset UART 3"]
     #[inline(always)]
     pub fn uart3(&self) -> UART3_R {
-        UART3_R::new(((self.bits >> 18) & 0x01) != 0)
+        UART3_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - Reset I2C Master 0"]
     #[inline(always)]
     pub fn i2cm0(&self) -> I2CM0_R {
-        I2CM0_R::new(((self.bits >> 19) & 0x01) != 0)
+        I2CM0_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 20 - Reset I2C Master 1"]
     #[inline(always)]
     pub fn i2cm1(&self) -> I2CM1_R {
-        I2CM1_R::new(((self.bits >> 20) & 0x01) != 0)
+        I2CM1_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 21 - Reset I2C Master 2"]
     #[inline(always)]
     pub fn i2cm2(&self) -> I2CM2_R {
-        I2CM2_R::new(((self.bits >> 21) & 0x01) != 0)
+        I2CM2_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 22 - Reset I2C Slave"]
     #[inline(always)]
     pub fn i2cs(&self) -> I2CS_R {
-        I2CS_R::new(((self.bits >> 22) & 0x01) != 0)
+        I2CS_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 23 - Reset SPI Master 0"]
     #[inline(always)]
     pub fn spim0(&self) -> SPIM0_R {
-        SPIM0_R::new(((self.bits >> 23) & 0x01) != 0)
+        SPIM0_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 24 - Reset SPI Master 1"]
     #[inline(always)]
     pub fn spim1(&self) -> SPIM1_R {
-        SPIM1_R::new(((self.bits >> 24) & 0x01) != 0)
+        SPIM1_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 25 - Reset SPI Master 2"]
     #[inline(always)]
     pub fn spim2(&self) -> SPIM2_R {
-        SPIM2_R::new(((self.bits >> 25) & 0x01) != 0)
+        SPIM2_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 26 - Reset SPI Bridge"]
     #[inline(always)]
     pub fn spib(&self) -> SPIB_R {
-        SPIB_R::new(((self.bits >> 26) & 0x01) != 0)
+        SPIB_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 27 - Reset 1-Wire Master"]
     #[inline(always)]
     pub fn owm(&self) -> OWM_R {
-        OWM_R::new(((self.bits >> 27) & 0x01) != 0)
+        OWM_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - Reset ADC"]
     #[inline(always)]
     pub fn adc(&self) -> ADC_R {
-        ADC_R::new(((self.bits >> 28) & 0x01) != 0)
+        ADC_R::new(((self.bits >> 28) & 1) != 0)
     }
 }
 impl W {
