@@ -35,7 +35,7 @@ impl From<crate::W<WUD_SEEN0_SPEC>> for W {
     }
 }
 #[doc = "Field `gpio0` reader - Wake-Up Detect Status for P0.0"]
-pub struct GPIO0_R(crate::FieldReader<bool, bool>);
+pub struct GPIO0_R(crate::FieldReader<bool>);
 impl GPIO0_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,14 +43,14 @@ impl GPIO0_R {
     }
 }
 impl core::ops::Deref for GPIO0_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio1` reader - Wake-Up Detect Status for P0.1"]
-pub struct GPIO1_R(crate::FieldReader<bool, bool>);
+pub struct GPIO1_R(crate::FieldReader<bool>);
 impl GPIO1_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -58,14 +58,14 @@ impl GPIO1_R {
     }
 }
 impl core::ops::Deref for GPIO1_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio2` reader - Wake-Up Detect Status for P0.2"]
-pub struct GPIO2_R(crate::FieldReader<bool, bool>);
+pub struct GPIO2_R(crate::FieldReader<bool>);
 impl GPIO2_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -73,14 +73,14 @@ impl GPIO2_R {
     }
 }
 impl core::ops::Deref for GPIO2_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio3` reader - Wake-Up Detect Status for P0.3"]
-pub struct GPIO3_R(crate::FieldReader<bool, bool>);
+pub struct GPIO3_R(crate::FieldReader<bool>);
 impl GPIO3_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -88,14 +88,14 @@ impl GPIO3_R {
     }
 }
 impl core::ops::Deref for GPIO3_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio4` reader - Wake-Up Detect Status for P0.4"]
-pub struct GPIO4_R(crate::FieldReader<bool, bool>);
+pub struct GPIO4_R(crate::FieldReader<bool>);
 impl GPIO4_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -103,14 +103,14 @@ impl GPIO4_R {
     }
 }
 impl core::ops::Deref for GPIO4_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio5` reader - Wake-Up Detect Status for P0.5"]
-pub struct GPIO5_R(crate::FieldReader<bool, bool>);
+pub struct GPIO5_R(crate::FieldReader<bool>);
 impl GPIO5_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -118,14 +118,14 @@ impl GPIO5_R {
     }
 }
 impl core::ops::Deref for GPIO5_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio6` reader - Wake-Up Detect Status for P0.6"]
-pub struct GPIO6_R(crate::FieldReader<bool, bool>);
+pub struct GPIO6_R(crate::FieldReader<bool>);
 impl GPIO6_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -133,14 +133,14 @@ impl GPIO6_R {
     }
 }
 impl core::ops::Deref for GPIO6_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio7` reader - Wake-Up Detect Status for P0.7"]
-pub struct GPIO7_R(crate::FieldReader<bool, bool>);
+pub struct GPIO7_R(crate::FieldReader<bool>);
 impl GPIO7_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -148,14 +148,14 @@ impl GPIO7_R {
     }
 }
 impl core::ops::Deref for GPIO7_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio8` reader - Wake-Up Detect Status for P1.0"]
-pub struct GPIO8_R(crate::FieldReader<bool, bool>);
+pub struct GPIO8_R(crate::FieldReader<bool>);
 impl GPIO8_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -163,14 +163,14 @@ impl GPIO8_R {
     }
 }
 impl core::ops::Deref for GPIO8_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio9` reader - Wake-Up Detect Status for P1.1"]
-pub struct GPIO9_R(crate::FieldReader<bool, bool>);
+pub struct GPIO9_R(crate::FieldReader<bool>);
 impl GPIO9_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -178,14 +178,14 @@ impl GPIO9_R {
     }
 }
 impl core::ops::Deref for GPIO9_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio10` reader - Wake-Up Detect Status for P1.2"]
-pub struct GPIO10_R(crate::FieldReader<bool, bool>);
+pub struct GPIO10_R(crate::FieldReader<bool>);
 impl GPIO10_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -193,14 +193,14 @@ impl GPIO10_R {
     }
 }
 impl core::ops::Deref for GPIO10_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio11` reader - Wake-Up Detect Status for P1.3"]
-pub struct GPIO11_R(crate::FieldReader<bool, bool>);
+pub struct GPIO11_R(crate::FieldReader<bool>);
 impl GPIO11_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -208,14 +208,14 @@ impl GPIO11_R {
     }
 }
 impl core::ops::Deref for GPIO11_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio12` reader - Wake-Up Detect Status for P1.4"]
-pub struct GPIO12_R(crate::FieldReader<bool, bool>);
+pub struct GPIO12_R(crate::FieldReader<bool>);
 impl GPIO12_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -223,14 +223,14 @@ impl GPIO12_R {
     }
 }
 impl core::ops::Deref for GPIO12_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio13` reader - Wake-Up Detect Status for P1.5"]
-pub struct GPIO13_R(crate::FieldReader<bool, bool>);
+pub struct GPIO13_R(crate::FieldReader<bool>);
 impl GPIO13_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -238,14 +238,14 @@ impl GPIO13_R {
     }
 }
 impl core::ops::Deref for GPIO13_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio14` reader - Wake-Up Detect Status for P1.6"]
-pub struct GPIO14_R(crate::FieldReader<bool, bool>);
+pub struct GPIO14_R(crate::FieldReader<bool>);
 impl GPIO14_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -253,14 +253,14 @@ impl GPIO14_R {
     }
 }
 impl core::ops::Deref for GPIO14_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio15` reader - Wake-Up Detect Status for P1.7"]
-pub struct GPIO15_R(crate::FieldReader<bool, bool>);
+pub struct GPIO15_R(crate::FieldReader<bool>);
 impl GPIO15_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -268,14 +268,14 @@ impl GPIO15_R {
     }
 }
 impl core::ops::Deref for GPIO15_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio16` reader - Wake-Up Detect Status for P2.0"]
-pub struct GPIO16_R(crate::FieldReader<bool, bool>);
+pub struct GPIO16_R(crate::FieldReader<bool>);
 impl GPIO16_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -283,14 +283,14 @@ impl GPIO16_R {
     }
 }
 impl core::ops::Deref for GPIO16_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio17` reader - Wake-Up Detect Status for P2.1"]
-pub struct GPIO17_R(crate::FieldReader<bool, bool>);
+pub struct GPIO17_R(crate::FieldReader<bool>);
 impl GPIO17_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -298,14 +298,14 @@ impl GPIO17_R {
     }
 }
 impl core::ops::Deref for GPIO17_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio18` reader - Wake-Up Detect Status for P2.2"]
-pub struct GPIO18_R(crate::FieldReader<bool, bool>);
+pub struct GPIO18_R(crate::FieldReader<bool>);
 impl GPIO18_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -313,14 +313,14 @@ impl GPIO18_R {
     }
 }
 impl core::ops::Deref for GPIO18_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio19` reader - Wake-Up Detect Status for P2.3"]
-pub struct GPIO19_R(crate::FieldReader<bool, bool>);
+pub struct GPIO19_R(crate::FieldReader<bool>);
 impl GPIO19_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -328,14 +328,14 @@ impl GPIO19_R {
     }
 }
 impl core::ops::Deref for GPIO19_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio20` reader - Wake-Up Detect Status for P2.4"]
-pub struct GPIO20_R(crate::FieldReader<bool, bool>);
+pub struct GPIO20_R(crate::FieldReader<bool>);
 impl GPIO20_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -343,14 +343,14 @@ impl GPIO20_R {
     }
 }
 impl core::ops::Deref for GPIO20_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio21` reader - Wake-Up Detect Status for P2.5"]
-pub struct GPIO21_R(crate::FieldReader<bool, bool>);
+pub struct GPIO21_R(crate::FieldReader<bool>);
 impl GPIO21_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -358,14 +358,14 @@ impl GPIO21_R {
     }
 }
 impl core::ops::Deref for GPIO21_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio22` reader - Wake-Up Detect Status for P2.6"]
-pub struct GPIO22_R(crate::FieldReader<bool, bool>);
+pub struct GPIO22_R(crate::FieldReader<bool>);
 impl GPIO22_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -373,14 +373,14 @@ impl GPIO22_R {
     }
 }
 impl core::ops::Deref for GPIO22_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio23` reader - Wake-Up Detect Status for P2.7"]
-pub struct GPIO23_R(crate::FieldReader<bool, bool>);
+pub struct GPIO23_R(crate::FieldReader<bool>);
 impl GPIO23_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -388,14 +388,14 @@ impl GPIO23_R {
     }
 }
 impl core::ops::Deref for GPIO23_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio24` reader - Wake-Up Detect Status for P3.0"]
-pub struct GPIO24_R(crate::FieldReader<bool, bool>);
+pub struct GPIO24_R(crate::FieldReader<bool>);
 impl GPIO24_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -403,14 +403,14 @@ impl GPIO24_R {
     }
 }
 impl core::ops::Deref for GPIO24_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio25` reader - Wake-Up Detect Status for P3.1"]
-pub struct GPIO25_R(crate::FieldReader<bool, bool>);
+pub struct GPIO25_R(crate::FieldReader<bool>);
 impl GPIO25_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -418,14 +418,14 @@ impl GPIO25_R {
     }
 }
 impl core::ops::Deref for GPIO25_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio26` reader - Wake-Up Detect Status for P3.2"]
-pub struct GPIO26_R(crate::FieldReader<bool, bool>);
+pub struct GPIO26_R(crate::FieldReader<bool>);
 impl GPIO26_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -433,14 +433,14 @@ impl GPIO26_R {
     }
 }
 impl core::ops::Deref for GPIO26_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio27` reader - Wake-Up Detect Status for P3.3"]
-pub struct GPIO27_R(crate::FieldReader<bool, bool>);
+pub struct GPIO27_R(crate::FieldReader<bool>);
 impl GPIO27_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -448,14 +448,14 @@ impl GPIO27_R {
     }
 }
 impl core::ops::Deref for GPIO27_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio28` reader - Wake-Up Detect Status for P3.4"]
-pub struct GPIO28_R(crate::FieldReader<bool, bool>);
+pub struct GPIO28_R(crate::FieldReader<bool>);
 impl GPIO28_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -463,14 +463,14 @@ impl GPIO28_R {
     }
 }
 impl core::ops::Deref for GPIO28_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio29` reader - Wake-Up Detect Status for P3.5"]
-pub struct GPIO29_R(crate::FieldReader<bool, bool>);
+pub struct GPIO29_R(crate::FieldReader<bool>);
 impl GPIO29_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -478,14 +478,14 @@ impl GPIO29_R {
     }
 }
 impl core::ops::Deref for GPIO29_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio30` reader - Wake-Up Detect Status for P3.6"]
-pub struct GPIO30_R(crate::FieldReader<bool, bool>);
+pub struct GPIO30_R(crate::FieldReader<bool>);
 impl GPIO30_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -493,14 +493,14 @@ impl GPIO30_R {
     }
 }
 impl core::ops::Deref for GPIO30_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `gpio31` reader - Wake-Up Detect Status for P3.7"]
-pub struct GPIO31_R(crate::FieldReader<bool, bool>);
+pub struct GPIO31_R(crate::FieldReader<bool>);
 impl GPIO31_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -508,7 +508,7 @@ impl GPIO31_R {
     }
 }
 impl core::ops::Deref for GPIO31_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -518,162 +518,162 @@ impl R {
     #[doc = "Bit 0 - Wake-Up Detect Status for P0.0"]
     #[inline(always)]
     pub fn gpio0(&self) -> GPIO0_R {
-        GPIO0_R::new((self.bits & 0x01) != 0)
+        GPIO0_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - Wake-Up Detect Status for P0.1"]
     #[inline(always)]
     pub fn gpio1(&self) -> GPIO1_R {
-        GPIO1_R::new(((self.bits >> 1) & 0x01) != 0)
+        GPIO1_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - Wake-Up Detect Status for P0.2"]
     #[inline(always)]
     pub fn gpio2(&self) -> GPIO2_R {
-        GPIO2_R::new(((self.bits >> 2) & 0x01) != 0)
+        GPIO2_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - Wake-Up Detect Status for P0.3"]
     #[inline(always)]
     pub fn gpio3(&self) -> GPIO3_R {
-        GPIO3_R::new(((self.bits >> 3) & 0x01) != 0)
+        GPIO3_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - Wake-Up Detect Status for P0.4"]
     #[inline(always)]
     pub fn gpio4(&self) -> GPIO4_R {
-        GPIO4_R::new(((self.bits >> 4) & 0x01) != 0)
+        GPIO4_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - Wake-Up Detect Status for P0.5"]
     #[inline(always)]
     pub fn gpio5(&self) -> GPIO5_R {
-        GPIO5_R::new(((self.bits >> 5) & 0x01) != 0)
+        GPIO5_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - Wake-Up Detect Status for P0.6"]
     #[inline(always)]
     pub fn gpio6(&self) -> GPIO6_R {
-        GPIO6_R::new(((self.bits >> 6) & 0x01) != 0)
+        GPIO6_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - Wake-Up Detect Status for P0.7"]
     #[inline(always)]
     pub fn gpio7(&self) -> GPIO7_R {
-        GPIO7_R::new(((self.bits >> 7) & 0x01) != 0)
+        GPIO7_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - Wake-Up Detect Status for P1.0"]
     #[inline(always)]
     pub fn gpio8(&self) -> GPIO8_R {
-        GPIO8_R::new(((self.bits >> 8) & 0x01) != 0)
+        GPIO8_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - Wake-Up Detect Status for P1.1"]
     #[inline(always)]
     pub fn gpio9(&self) -> GPIO9_R {
-        GPIO9_R::new(((self.bits >> 9) & 0x01) != 0)
+        GPIO9_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - Wake-Up Detect Status for P1.2"]
     #[inline(always)]
     pub fn gpio10(&self) -> GPIO10_R {
-        GPIO10_R::new(((self.bits >> 10) & 0x01) != 0)
+        GPIO10_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - Wake-Up Detect Status for P1.3"]
     #[inline(always)]
     pub fn gpio11(&self) -> GPIO11_R {
-        GPIO11_R::new(((self.bits >> 11) & 0x01) != 0)
+        GPIO11_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - Wake-Up Detect Status for P1.4"]
     #[inline(always)]
     pub fn gpio12(&self) -> GPIO12_R {
-        GPIO12_R::new(((self.bits >> 12) & 0x01) != 0)
+        GPIO12_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - Wake-Up Detect Status for P1.5"]
     #[inline(always)]
     pub fn gpio13(&self) -> GPIO13_R {
-        GPIO13_R::new(((self.bits >> 13) & 0x01) != 0)
+        GPIO13_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - Wake-Up Detect Status for P1.6"]
     #[inline(always)]
     pub fn gpio14(&self) -> GPIO14_R {
-        GPIO14_R::new(((self.bits >> 14) & 0x01) != 0)
+        GPIO14_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - Wake-Up Detect Status for P1.7"]
     #[inline(always)]
     pub fn gpio15(&self) -> GPIO15_R {
-        GPIO15_R::new(((self.bits >> 15) & 0x01) != 0)
+        GPIO15_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 16 - Wake-Up Detect Status for P2.0"]
     #[inline(always)]
     pub fn gpio16(&self) -> GPIO16_R {
-        GPIO16_R::new(((self.bits >> 16) & 0x01) != 0)
+        GPIO16_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - Wake-Up Detect Status for P2.1"]
     #[inline(always)]
     pub fn gpio17(&self) -> GPIO17_R {
-        GPIO17_R::new(((self.bits >> 17) & 0x01) != 0)
+        GPIO17_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 18 - Wake-Up Detect Status for P2.2"]
     #[inline(always)]
     pub fn gpio18(&self) -> GPIO18_R {
-        GPIO18_R::new(((self.bits >> 18) & 0x01) != 0)
+        GPIO18_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - Wake-Up Detect Status for P2.3"]
     #[inline(always)]
     pub fn gpio19(&self) -> GPIO19_R {
-        GPIO19_R::new(((self.bits >> 19) & 0x01) != 0)
+        GPIO19_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 20 - Wake-Up Detect Status for P2.4"]
     #[inline(always)]
     pub fn gpio20(&self) -> GPIO20_R {
-        GPIO20_R::new(((self.bits >> 20) & 0x01) != 0)
+        GPIO20_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 21 - Wake-Up Detect Status for P2.5"]
     #[inline(always)]
     pub fn gpio21(&self) -> GPIO21_R {
-        GPIO21_R::new(((self.bits >> 21) & 0x01) != 0)
+        GPIO21_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 22 - Wake-Up Detect Status for P2.6"]
     #[inline(always)]
     pub fn gpio22(&self) -> GPIO22_R {
-        GPIO22_R::new(((self.bits >> 22) & 0x01) != 0)
+        GPIO22_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 23 - Wake-Up Detect Status for P2.7"]
     #[inline(always)]
     pub fn gpio23(&self) -> GPIO23_R {
-        GPIO23_R::new(((self.bits >> 23) & 0x01) != 0)
+        GPIO23_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 24 - Wake-Up Detect Status for P3.0"]
     #[inline(always)]
     pub fn gpio24(&self) -> GPIO24_R {
-        GPIO24_R::new(((self.bits >> 24) & 0x01) != 0)
+        GPIO24_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 25 - Wake-Up Detect Status for P3.1"]
     #[inline(always)]
     pub fn gpio25(&self) -> GPIO25_R {
-        GPIO25_R::new(((self.bits >> 25) & 0x01) != 0)
+        GPIO25_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 26 - Wake-Up Detect Status for P3.2"]
     #[inline(always)]
     pub fn gpio26(&self) -> GPIO26_R {
-        GPIO26_R::new(((self.bits >> 26) & 0x01) != 0)
+        GPIO26_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 27 - Wake-Up Detect Status for P3.3"]
     #[inline(always)]
     pub fn gpio27(&self) -> GPIO27_R {
-        GPIO27_R::new(((self.bits >> 27) & 0x01) != 0)
+        GPIO27_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - Wake-Up Detect Status for P3.4"]
     #[inline(always)]
     pub fn gpio28(&self) -> GPIO28_R {
-        GPIO28_R::new(((self.bits >> 28) & 0x01) != 0)
+        GPIO28_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 29 - Wake-Up Detect Status for P3.5"]
     #[inline(always)]
     pub fn gpio29(&self) -> GPIO29_R {
-        GPIO29_R::new(((self.bits >> 29) & 0x01) != 0)
+        GPIO29_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 30 - Wake-Up Detect Status for P3.6"]
     #[inline(always)]
     pub fn gpio30(&self) -> GPIO30_R {
-        GPIO30_R::new(((self.bits >> 30) & 0x01) != 0)
+        GPIO30_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 31 - Wake-Up Detect Status for P3.7"]
     #[inline(always)]
     pub fn gpio31(&self) -> GPIO31_R {
-        GPIO31_R::new(((self.bits >> 31) & 0x01) != 0)
+        GPIO31_R::new(((self.bits >> 31) & 1) != 0)
     }
 }
 impl W {
