@@ -35,7 +35,7 @@ impl From<crate::W<MSK_FLAGS_SPEC>> for W {
     }
 }
 #[doc = "Field `pwr_sys_reboot` reader - Mask for system reboot detect"]
-pub struct PWR_SYS_REBOOT_R(crate::FieldReader<bool, bool>);
+pub struct PWR_SYS_REBOOT_R(crate::FieldReader<bool>);
 impl PWR_SYS_REBOOT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl PWR_SYS_REBOOT_R {
     }
 }
 impl core::ops::Deref for PWR_SYS_REBOOT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,12 +67,12 @@ impl<'a> PWR_SYS_REBOOT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `pwr_power_fail` reader - Mask for previous power fail detect"]
-pub struct PWR_POWER_FAIL_R(crate::FieldReader<bool, bool>);
+pub struct PWR_POWER_FAIL_R(crate::FieldReader<bool>);
 impl PWR_POWER_FAIL_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -80,7 +80,7 @@ impl PWR_POWER_FAIL_R {
     }
 }
 impl core::ops::Deref for PWR_POWER_FAIL_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -104,12 +104,12 @@ impl<'a> PWR_POWER_FAIL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `pwr_boot_fail` reader - Mask for previous boot fail detect"]
-pub struct PWR_BOOT_FAIL_R(crate::FieldReader<bool, bool>);
+pub struct PWR_BOOT_FAIL_R(crate::FieldReader<bool>);
 impl PWR_BOOT_FAIL_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -117,7 +117,7 @@ impl PWR_BOOT_FAIL_R {
     }
 }
 impl core::ops::Deref for PWR_BOOT_FAIL_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -141,12 +141,12 @@ impl<'a> PWR_BOOT_FAIL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `pwr_flash_discharge` reader - Mask for flash discharge event"]
-pub struct PWR_FLASH_DISCHARGE_R(crate::FieldReader<bool, bool>);
+pub struct PWR_FLASH_DISCHARGE_R(crate::FieldReader<bool>);
 impl PWR_FLASH_DISCHARGE_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -154,7 +154,7 @@ impl PWR_FLASH_DISCHARGE_R {
     }
 }
 impl core::ops::Deref for PWR_FLASH_DISCHARGE_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -178,12 +178,12 @@ impl<'a> PWR_FLASH_DISCHARGE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `pwr_iowakeup` reader - Mask for GPIO wakeup event detect"]
-pub struct PWR_IOWAKEUP_R(crate::FieldReader<bool, bool>);
+pub struct PWR_IOWAKEUP_R(crate::FieldReader<bool>);
 impl PWR_IOWAKEUP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -191,7 +191,7 @@ impl PWR_IOWAKEUP_R {
     }
 }
 impl core::ops::Deref for PWR_IOWAKEUP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -215,12 +215,12 @@ impl<'a> PWR_IOWAKEUP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `pwr_vdd12_rst_bad` reader - Mask for VDD12 rst event"]
-pub struct PWR_VDD12_RST_BAD_R(crate::FieldReader<bool, bool>);
+pub struct PWR_VDD12_RST_BAD_R(crate::FieldReader<bool>);
 impl PWR_VDD12_RST_BAD_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -228,7 +228,7 @@ impl PWR_VDD12_RST_BAD_R {
     }
 }
 impl core::ops::Deref for PWR_VDD12_RST_BAD_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -252,12 +252,12 @@ impl<'a> PWR_VDD12_RST_BAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `pwr_vdd18_rst_bad` reader - Mask for VDD18 rst event"]
-pub struct PWR_VDD18_RST_BAD_R(crate::FieldReader<bool, bool>);
+pub struct PWR_VDD18_RST_BAD_R(crate::FieldReader<bool>);
 impl PWR_VDD18_RST_BAD_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -265,7 +265,7 @@ impl PWR_VDD18_RST_BAD_R {
     }
 }
 impl core::ops::Deref for PWR_VDD18_RST_BAD_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -289,12 +289,12 @@ impl<'a> PWR_VDD18_RST_BAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `pwr_vrtc_rst_bad` reader - Mask for VRTC rst event"]
-pub struct PWR_VRTC_RST_BAD_R(crate::FieldReader<bool, bool>);
+pub struct PWR_VRTC_RST_BAD_R(crate::FieldReader<bool>);
 impl PWR_VRTC_RST_BAD_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -302,7 +302,7 @@ impl PWR_VRTC_RST_BAD_R {
     }
 }
 impl core::ops::Deref for PWR_VRTC_RST_BAD_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -326,12 +326,12 @@ impl<'a> PWR_VRTC_RST_BAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `pwr_vddb_rst_bad` reader - Mask for VDDB rst event"]
-pub struct PWR_VDDB_RST_BAD_R(crate::FieldReader<bool, bool>);
+pub struct PWR_VDDB_RST_BAD_R(crate::FieldReader<bool>);
 impl PWR_VDDB_RST_BAD_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -339,7 +339,7 @@ impl PWR_VDDB_RST_BAD_R {
     }
 }
 impl core::ops::Deref for PWR_VDDB_RST_BAD_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -363,12 +363,12 @@ impl<'a> PWR_VDDB_RST_BAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `pwr_tvdd12_rst_bad` reader - Mask for TVDD12 rst event"]
-pub struct PWR_TVDD12_RST_BAD_R(crate::FieldReader<bool, bool>);
+pub struct PWR_TVDD12_RST_BAD_R(crate::FieldReader<bool>);
 impl PWR_TVDD12_RST_BAD_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -376,7 +376,7 @@ impl PWR_TVDD12_RST_BAD_R {
     }
 }
 impl core::ops::Deref for PWR_TVDD12_RST_BAD_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -400,12 +400,12 @@ impl<'a> PWR_TVDD12_RST_BAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `pwr_por18z_fail_latch` reader - Mask for POR18 powerfail event"]
-pub struct PWR_POR18Z_FAIL_LATCH_R(crate::FieldReader<bool, bool>);
+pub struct PWR_POR18Z_FAIL_LATCH_R(crate::FieldReader<bool>);
 impl PWR_POR18Z_FAIL_LATCH_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -413,7 +413,7 @@ impl PWR_POR18Z_FAIL_LATCH_R {
     }
 }
 impl core::ops::Deref for PWR_POR18Z_FAIL_LATCH_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -437,12 +437,12 @@ impl<'a> PWR_POR18Z_FAIL_LATCH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `rtc_cmpr0` reader - Mask for RTC compare 0 event"]
-pub struct RTC_CMPR0_R(crate::FieldReader<bool, bool>);
+pub struct RTC_CMPR0_R(crate::FieldReader<bool>);
 impl RTC_CMPR0_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -450,7 +450,7 @@ impl RTC_CMPR0_R {
     }
 }
 impl core::ops::Deref for RTC_CMPR0_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -474,12 +474,12 @@ impl<'a> RTC_CMPR0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `rtc_cmpr1` reader - Mask for RTC compare 1 event"]
-pub struct RTC_CMPR1_R(crate::FieldReader<bool, bool>);
+pub struct RTC_CMPR1_R(crate::FieldReader<bool>);
 impl RTC_CMPR1_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -487,7 +487,7 @@ impl RTC_CMPR1_R {
     }
 }
 impl core::ops::Deref for RTC_CMPR1_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -511,12 +511,12 @@ impl<'a> RTC_CMPR1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `rtc_prescale_cmp` reader - Mask for RTC prescale compare event"]
-pub struct RTC_PRESCALE_CMP_R(crate::FieldReader<bool, bool>);
+pub struct RTC_PRESCALE_CMP_R(crate::FieldReader<bool>);
 impl RTC_PRESCALE_CMP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -524,7 +524,7 @@ impl RTC_PRESCALE_CMP_R {
     }
 }
 impl core::ops::Deref for RTC_PRESCALE_CMP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -548,12 +548,12 @@ impl<'a> RTC_PRESCALE_CMP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `rtc_rollover` reader - Mask for RTC rollover event"]
-pub struct RTC_ROLLOVER_R(crate::FieldReader<bool, bool>);
+pub struct RTC_ROLLOVER_R(crate::FieldReader<bool>);
 impl RTC_ROLLOVER_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -561,7 +561,7 @@ impl RTC_ROLLOVER_R {
     }
 }
 impl core::ops::Deref for RTC_ROLLOVER_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -585,12 +585,12 @@ impl<'a> RTC_ROLLOVER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
 #[doc = "Field `pwr_usb_plug_wakeup` reader - Mask for USB plug connect event"]
-pub struct PWR_USB_PLUG_WAKEUP_R(crate::FieldReader<bool, bool>);
+pub struct PWR_USB_PLUG_WAKEUP_R(crate::FieldReader<bool>);
 impl PWR_USB_PLUG_WAKEUP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -598,7 +598,7 @@ impl PWR_USB_PLUG_WAKEUP_R {
     }
 }
 impl core::ops::Deref for PWR_USB_PLUG_WAKEUP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -622,12 +622,12 @@ impl<'a> PWR_USB_PLUG_WAKEUP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
 #[doc = "Field `pwr_usb_remove_wakeup` reader - Mask for USB plug disconnect event"]
-pub struct PWR_USB_REMOVE_WAKEUP_R(crate::FieldReader<bool, bool>);
+pub struct PWR_USB_REMOVE_WAKEUP_R(crate::FieldReader<bool>);
 impl PWR_USB_REMOVE_WAKEUP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -635,7 +635,7 @@ impl PWR_USB_REMOVE_WAKEUP_R {
     }
 }
 impl core::ops::Deref for PWR_USB_REMOVE_WAKEUP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -659,12 +659,12 @@ impl<'a> PWR_USB_REMOVE_WAKEUP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
 #[doc = "Field `pwr_tvdd12_bad` reader - Mask for TVDD12 power fail event"]
-pub struct PWR_TVDD12_BAD_R(crate::FieldReader<bool, bool>);
+pub struct PWR_TVDD12_BAD_R(crate::FieldReader<bool>);
 impl PWR_TVDD12_BAD_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -672,7 +672,7 @@ impl PWR_TVDD12_BAD_R {
     }
 }
 impl core::ops::Deref for PWR_TVDD12_BAD_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -696,7 +696,7 @@ impl<'a> PWR_TVDD12_BAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
@@ -704,92 +704,92 @@ impl R {
     #[doc = "Bit 1 - Mask for system reboot detect"]
     #[inline(always)]
     pub fn pwr_sys_reboot(&self) -> PWR_SYS_REBOOT_R {
-        PWR_SYS_REBOOT_R::new(((self.bits >> 1) & 0x01) != 0)
+        PWR_SYS_REBOOT_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - Mask for previous power fail detect"]
     #[inline(always)]
     pub fn pwr_power_fail(&self) -> PWR_POWER_FAIL_R {
-        PWR_POWER_FAIL_R::new(((self.bits >> 2) & 0x01) != 0)
+        PWR_POWER_FAIL_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - Mask for previous boot fail detect"]
     #[inline(always)]
     pub fn pwr_boot_fail(&self) -> PWR_BOOT_FAIL_R {
-        PWR_BOOT_FAIL_R::new(((self.bits >> 3) & 0x01) != 0)
+        PWR_BOOT_FAIL_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - Mask for flash discharge event"]
     #[inline(always)]
     pub fn pwr_flash_discharge(&self) -> PWR_FLASH_DISCHARGE_R {
-        PWR_FLASH_DISCHARGE_R::new(((self.bits >> 4) & 0x01) != 0)
+        PWR_FLASH_DISCHARGE_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - Mask for GPIO wakeup event detect"]
     #[inline(always)]
     pub fn pwr_iowakeup(&self) -> PWR_IOWAKEUP_R {
-        PWR_IOWAKEUP_R::new(((self.bits >> 5) & 0x01) != 0)
+        PWR_IOWAKEUP_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - Mask for VDD12 rst event"]
     #[inline(always)]
     pub fn pwr_vdd12_rst_bad(&self) -> PWR_VDD12_RST_BAD_R {
-        PWR_VDD12_RST_BAD_R::new(((self.bits >> 6) & 0x01) != 0)
+        PWR_VDD12_RST_BAD_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - Mask for VDD18 rst event"]
     #[inline(always)]
     pub fn pwr_vdd18_rst_bad(&self) -> PWR_VDD18_RST_BAD_R {
-        PWR_VDD18_RST_BAD_R::new(((self.bits >> 7) & 0x01) != 0)
+        PWR_VDD18_RST_BAD_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - Mask for VRTC rst event"]
     #[inline(always)]
     pub fn pwr_vrtc_rst_bad(&self) -> PWR_VRTC_RST_BAD_R {
-        PWR_VRTC_RST_BAD_R::new(((self.bits >> 8) & 0x01) != 0)
+        PWR_VRTC_RST_BAD_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - Mask for VDDB rst event"]
     #[inline(always)]
     pub fn pwr_vddb_rst_bad(&self) -> PWR_VDDB_RST_BAD_R {
-        PWR_VDDB_RST_BAD_R::new(((self.bits >> 9) & 0x01) != 0)
+        PWR_VDDB_RST_BAD_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - Mask for TVDD12 rst event"]
     #[inline(always)]
     pub fn pwr_tvdd12_rst_bad(&self) -> PWR_TVDD12_RST_BAD_R {
-        PWR_TVDD12_RST_BAD_R::new(((self.bits >> 10) & 0x01) != 0)
+        PWR_TVDD12_RST_BAD_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - Mask for POR18 powerfail event"]
     #[inline(always)]
     pub fn pwr_por18z_fail_latch(&self) -> PWR_POR18Z_FAIL_LATCH_R {
-        PWR_POR18Z_FAIL_LATCH_R::new(((self.bits >> 11) & 0x01) != 0)
+        PWR_POR18Z_FAIL_LATCH_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - Mask for RTC compare 0 event"]
     #[inline(always)]
     pub fn rtc_cmpr0(&self) -> RTC_CMPR0_R {
-        RTC_CMPR0_R::new(((self.bits >> 12) & 0x01) != 0)
+        RTC_CMPR0_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - Mask for RTC compare 1 event"]
     #[inline(always)]
     pub fn rtc_cmpr1(&self) -> RTC_CMPR1_R {
-        RTC_CMPR1_R::new(((self.bits >> 13) & 0x01) != 0)
+        RTC_CMPR1_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - Mask for RTC prescale compare event"]
     #[inline(always)]
     pub fn rtc_prescale_cmp(&self) -> RTC_PRESCALE_CMP_R {
-        RTC_PRESCALE_CMP_R::new(((self.bits >> 14) & 0x01) != 0)
+        RTC_PRESCALE_CMP_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - Mask for RTC rollover event"]
     #[inline(always)]
     pub fn rtc_rollover(&self) -> RTC_ROLLOVER_R {
-        RTC_ROLLOVER_R::new(((self.bits >> 15) & 0x01) != 0)
+        RTC_ROLLOVER_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 16 - Mask for USB plug connect event"]
     #[inline(always)]
     pub fn pwr_usb_plug_wakeup(&self) -> PWR_USB_PLUG_WAKEUP_R {
-        PWR_USB_PLUG_WAKEUP_R::new(((self.bits >> 16) & 0x01) != 0)
+        PWR_USB_PLUG_WAKEUP_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - Mask for USB plug disconnect event"]
     #[inline(always)]
     pub fn pwr_usb_remove_wakeup(&self) -> PWR_USB_REMOVE_WAKEUP_R {
-        PWR_USB_REMOVE_WAKEUP_R::new(((self.bits >> 17) & 0x01) != 0)
+        PWR_USB_REMOVE_WAKEUP_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 18 - Mask for TVDD12 power fail event"]
     #[inline(always)]
     pub fn pwr_tvdd12_bad(&self) -> PWR_TVDD12_BAD_R {
-        PWR_TVDD12_BAD_R::new(((self.bits >> 18) & 0x01) != 0)
+        PWR_TVDD12_BAD_R::new(((self.bits >> 18) & 1) != 0)
     }
 }
 impl W {
