@@ -35,7 +35,7 @@ impl From<crate::W<REG0_SPEC>> for W {
     }
 }
 #[doc = "Field `pwr_lp1` reader - Shutdown Power Mode Select"]
-pub struct PWR_LP1_R(crate::FieldReader<bool, bool>);
+pub struct PWR_LP1_R(crate::FieldReader<bool>);
 impl PWR_LP1_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl PWR_LP1_R {
     }
 }
 impl core::ops::Deref for PWR_LP1_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,12 +67,12 @@ impl<'a> PWR_LP1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `pwr_first_boot` reader - Wake on First Boot"]
-pub struct PWR_FIRST_BOOT_R(crate::FieldReader<bool, bool>);
+pub struct PWR_FIRST_BOOT_R(crate::FieldReader<bool>);
 impl PWR_FIRST_BOOT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -80,7 +80,7 @@ impl PWR_FIRST_BOOT_R {
     }
 }
 impl core::ops::Deref for PWR_FIRST_BOOT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -104,7 +104,7 @@ impl<'a> PWR_FIRST_BOOT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -126,12 +126,12 @@ impl<'a> PWR_SYS_REBOOT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `pwr_flashen_run` reader - Enable Flash Operation during Run Mode"]
-pub struct PWR_FLASHEN_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_FLASHEN_RUN_R(crate::FieldReader<bool>);
 impl PWR_FLASHEN_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -139,7 +139,7 @@ impl PWR_FLASHEN_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_FLASHEN_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -163,12 +163,12 @@ impl<'a> PWR_FLASHEN_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `pwr_flashen_slp` reader - Enable Flash Operation during Sleep Mode"]
-pub struct PWR_FLASHEN_SLP_R(crate::FieldReader<bool, bool>);
+pub struct PWR_FLASHEN_SLP_R(crate::FieldReader<bool>);
 impl PWR_FLASHEN_SLP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -176,7 +176,7 @@ impl PWR_FLASHEN_SLP_R {
     }
 }
 impl core::ops::Deref for PWR_FLASHEN_SLP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -200,12 +200,12 @@ impl<'a> PWR_FLASHEN_SLP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `pwr_retregen_run` reader - Enable Retention Regulator Operation during Run Mode"]
-pub struct PWR_RETREGEN_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_RETREGEN_RUN_R(crate::FieldReader<bool>);
 impl PWR_RETREGEN_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -213,7 +213,7 @@ impl PWR_RETREGEN_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_RETREGEN_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -237,12 +237,12 @@ impl<'a> PWR_RETREGEN_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `pwr_retregen_slp` reader - Enable Retention Regulator Operation during Sleep Mode"]
-pub struct PWR_RETREGEN_SLP_R(crate::FieldReader<bool, bool>);
+pub struct PWR_RETREGEN_SLP_R(crate::FieldReader<bool>);
 impl PWR_RETREGEN_SLP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -250,7 +250,7 @@ impl PWR_RETREGEN_SLP_R {
     }
 }
 impl core::ops::Deref for PWR_RETREGEN_SLP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -274,12 +274,12 @@ impl<'a> PWR_RETREGEN_SLP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `pwr_roen_run` reader - Enable 96MHz System Relaxation Oscillator in Run Mode"]
-pub struct PWR_ROEN_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_ROEN_RUN_R(crate::FieldReader<bool>);
 impl PWR_ROEN_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -287,7 +287,7 @@ impl PWR_ROEN_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_ROEN_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -311,12 +311,12 @@ impl<'a> PWR_ROEN_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `pwr_roen_slp` reader - Enable 96MHz System Relaxation Oscillator in Sleep Mode"]
-pub struct PWR_ROEN_SLP_R(crate::FieldReader<bool, bool>);
+pub struct PWR_ROEN_SLP_R(crate::FieldReader<bool>);
 impl PWR_ROEN_SLP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -324,7 +324,7 @@ impl PWR_ROEN_SLP_R {
     }
 }
 impl core::ops::Deref for PWR_ROEN_SLP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -348,12 +348,12 @@ impl<'a> PWR_ROEN_SLP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `pwr_nren_run` reader - Enable Nano Oscillator in Run Mode"]
-pub struct PWR_NREN_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_NREN_RUN_R(crate::FieldReader<bool>);
 impl PWR_NREN_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -361,7 +361,7 @@ impl PWR_NREN_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_NREN_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -385,12 +385,12 @@ impl<'a> PWR_NREN_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `pwr_nren_slp` reader - Enable Nano Oscillator in Sleep Mode"]
-pub struct PWR_NREN_SLP_R(crate::FieldReader<bool, bool>);
+pub struct PWR_NREN_SLP_R(crate::FieldReader<bool>);
 impl PWR_NREN_SLP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -398,7 +398,7 @@ impl PWR_NREN_SLP_R {
     }
 }
 impl core::ops::Deref for PWR_NREN_SLP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -422,12 +422,12 @@ impl<'a> PWR_NREN_SLP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `pwr_rtcen_run` reader - Enable Real Time Clock Operation during Run Mode"]
-pub struct PWR_RTCEN_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_RTCEN_RUN_R(crate::FieldReader<bool>);
 impl PWR_RTCEN_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -435,7 +435,7 @@ impl PWR_RTCEN_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_RTCEN_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -459,12 +459,12 @@ impl<'a> PWR_RTCEN_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `pwr_rtcen_slp` reader - Enable Real Time Clock Operation during Sleep Mode"]
-pub struct PWR_RTCEN_SLP_R(crate::FieldReader<bool, bool>);
+pub struct PWR_RTCEN_SLP_R(crate::FieldReader<bool>);
 impl PWR_RTCEN_SLP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -472,7 +472,7 @@ impl PWR_RTCEN_SLP_R {
     }
 }
 impl core::ops::Deref for PWR_RTCEN_SLP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -496,12 +496,12 @@ impl<'a> PWR_RTCEN_SLP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `pwr_svm12en_run` reader - Enable VDD12_SW SVM operation during Run Mode"]
-pub struct PWR_SVM12EN_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_SVM12EN_RUN_R(crate::FieldReader<bool>);
 impl PWR_SVM12EN_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -509,7 +509,7 @@ impl PWR_SVM12EN_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_SVM12EN_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -533,12 +533,12 @@ impl<'a> PWR_SVM12EN_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `pwr_svm18en_run` reader - Enable VDD18_SW SVM operation during Run Mode"]
-pub struct PWR_SVM18EN_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_SVM18EN_RUN_R(crate::FieldReader<bool>);
 impl PWR_SVM18EN_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -546,7 +546,7 @@ impl PWR_SVM18EN_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_SVM18EN_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -570,12 +570,12 @@ impl<'a> PWR_SVM18EN_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
 #[doc = "Field `pwr_svmrtcen_run` reader - Enable VRTC SVM operation during Run Mode"]
-pub struct PWR_SVMRTCEN_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_SVMRTCEN_RUN_R(crate::FieldReader<bool>);
 impl PWR_SVMRTCEN_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -583,7 +583,7 @@ impl PWR_SVMRTCEN_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_SVMRTCEN_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -607,12 +607,12 @@ impl<'a> PWR_SVMRTCEN_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
 #[doc = "Field `pwr_svm_vddb_run` reader - Enable VDDB SVM operation during Run Mode"]
-pub struct PWR_SVM_VDDB_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_SVM_VDDB_RUN_R(crate::FieldReader<bool>);
 impl PWR_SVM_VDDB_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -620,7 +620,7 @@ impl PWR_SVM_VDDB_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_SVM_VDDB_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -644,12 +644,12 @@ impl<'a> PWR_SVM_VDDB_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
 #[doc = "Field `pwr_svmtvdd12en_run` reader - Enable TVDD12 SVM operation during Run Mode"]
-pub struct PWR_SVMTVDD12EN_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_SVMTVDD12EN_RUN_R(crate::FieldReader<bool>);
 impl PWR_SVMTVDD12EN_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -657,7 +657,7 @@ impl PWR_SVMTVDD12EN_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_SVMTVDD12EN_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -681,12 +681,12 @@ impl<'a> PWR_SVMTVDD12EN_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
 #[doc = "Field `pwr_vdd12_swen_run` reader - Enable VDD12 switching during Run Mode"]
-pub struct PWR_VDD12_SWEN_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_VDD12_SWEN_RUN_R(crate::FieldReader<bool>);
 impl PWR_VDD12_SWEN_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -694,7 +694,7 @@ impl PWR_VDD12_SWEN_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_VDD12_SWEN_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -718,12 +718,12 @@ impl<'a> PWR_VDD12_SWEN_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
 #[doc = "Field `pwr_vdd12_swen_slp` reader - Enable VDD12 switching during Sleep Mode"]
-pub struct PWR_VDD12_SWEN_SLP_R(crate::FieldReader<bool, bool>);
+pub struct PWR_VDD12_SWEN_SLP_R(crate::FieldReader<bool>);
 impl PWR_VDD12_SWEN_SLP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -731,7 +731,7 @@ impl PWR_VDD12_SWEN_SLP_R {
     }
 }
 impl core::ops::Deref for PWR_VDD12_SWEN_SLP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -755,12 +755,12 @@ impl<'a> PWR_VDD12_SWEN_SLP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
 #[doc = "Field `pwr_vdd18_swen_run` reader - Enable VDD18 switching during Run Mode"]
-pub struct PWR_VDD18_SWEN_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_VDD18_SWEN_RUN_R(crate::FieldReader<bool>);
 impl PWR_VDD18_SWEN_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -768,7 +768,7 @@ impl PWR_VDD18_SWEN_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_VDD18_SWEN_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -792,12 +792,12 @@ impl<'a> PWR_VDD18_SWEN_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
 #[doc = "Field `pwr_vdd18_swen_slp` reader - Enable VDD18 switching during Sleep Mode"]
-pub struct PWR_VDD18_SWEN_SLP_R(crate::FieldReader<bool, bool>);
+pub struct PWR_VDD18_SWEN_SLP_R(crate::FieldReader<bool>);
 impl PWR_VDD18_SWEN_SLP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -805,7 +805,7 @@ impl PWR_VDD18_SWEN_SLP_R {
     }
 }
 impl core::ops::Deref for PWR_VDD18_SWEN_SLP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -829,12 +829,12 @@ impl<'a> PWR_VDD18_SWEN_SLP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
 #[doc = "Field `pwr_tvdd12_swen_run` reader - Enable TVDD12 switching during Run Mode"]
-pub struct PWR_TVDD12_SWEN_RUN_R(crate::FieldReader<bool, bool>);
+pub struct PWR_TVDD12_SWEN_RUN_R(crate::FieldReader<bool>);
 impl PWR_TVDD12_SWEN_RUN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -842,7 +842,7 @@ impl PWR_TVDD12_SWEN_RUN_R {
     }
 }
 impl core::ops::Deref for PWR_TVDD12_SWEN_RUN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -866,12 +866,12 @@ impl<'a> PWR_TVDD12_SWEN_RUN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
 #[doc = "Field `pwr_tvdd12_swen_slp` reader - Enable TVDD12 switching during Sleep Mode"]
-pub struct PWR_TVDD12_SWEN_SLP_R(crate::FieldReader<bool, bool>);
+pub struct PWR_TVDD12_SWEN_SLP_R(crate::FieldReader<bool>);
 impl PWR_TVDD12_SWEN_SLP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -879,7 +879,7 @@ impl PWR_TVDD12_SWEN_SLP_R {
     }
 }
 impl core::ops::Deref for PWR_TVDD12_SWEN_SLP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -903,7 +903,7 @@ impl<'a> PWR_TVDD12_SWEN_SLP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
@@ -911,117 +911,117 @@ impl R {
     #[doc = "Bit 0 - Shutdown Power Mode Select"]
     #[inline(always)]
     pub fn pwr_lp1(&self) -> PWR_LP1_R {
-        PWR_LP1_R::new((self.bits & 0x01) != 0)
+        PWR_LP1_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - Wake on First Boot"]
     #[inline(always)]
     pub fn pwr_first_boot(&self) -> PWR_FIRST_BOOT_R {
-        PWR_FIRST_BOOT_R::new(((self.bits >> 1) & 0x01) != 0)
+        PWR_FIRST_BOOT_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 3 - Enable Flash Operation during Run Mode"]
     #[inline(always)]
     pub fn pwr_flashen_run(&self) -> PWR_FLASHEN_RUN_R {
-        PWR_FLASHEN_RUN_R::new(((self.bits >> 3) & 0x01) != 0)
+        PWR_FLASHEN_RUN_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - Enable Flash Operation during Sleep Mode"]
     #[inline(always)]
     pub fn pwr_flashen_slp(&self) -> PWR_FLASHEN_SLP_R {
-        PWR_FLASHEN_SLP_R::new(((self.bits >> 4) & 0x01) != 0)
+        PWR_FLASHEN_SLP_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - Enable Retention Regulator Operation during Run Mode"]
     #[inline(always)]
     pub fn pwr_retregen_run(&self) -> PWR_RETREGEN_RUN_R {
-        PWR_RETREGEN_RUN_R::new(((self.bits >> 5) & 0x01) != 0)
+        PWR_RETREGEN_RUN_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - Enable Retention Regulator Operation during Sleep Mode"]
     #[inline(always)]
     pub fn pwr_retregen_slp(&self) -> PWR_RETREGEN_SLP_R {
-        PWR_RETREGEN_SLP_R::new(((self.bits >> 6) & 0x01) != 0)
+        PWR_RETREGEN_SLP_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - Enable 96MHz System Relaxation Oscillator in Run Mode"]
     #[inline(always)]
     pub fn pwr_roen_run(&self) -> PWR_ROEN_RUN_R {
-        PWR_ROEN_RUN_R::new(((self.bits >> 7) & 0x01) != 0)
+        PWR_ROEN_RUN_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - Enable 96MHz System Relaxation Oscillator in Sleep Mode"]
     #[inline(always)]
     pub fn pwr_roen_slp(&self) -> PWR_ROEN_SLP_R {
-        PWR_ROEN_SLP_R::new(((self.bits >> 8) & 0x01) != 0)
+        PWR_ROEN_SLP_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - Enable Nano Oscillator in Run Mode"]
     #[inline(always)]
     pub fn pwr_nren_run(&self) -> PWR_NREN_RUN_R {
-        PWR_NREN_RUN_R::new(((self.bits >> 9) & 0x01) != 0)
+        PWR_NREN_RUN_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - Enable Nano Oscillator in Sleep Mode"]
     #[inline(always)]
     pub fn pwr_nren_slp(&self) -> PWR_NREN_SLP_R {
-        PWR_NREN_SLP_R::new(((self.bits >> 10) & 0x01) != 0)
+        PWR_NREN_SLP_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - Enable Real Time Clock Operation during Run Mode"]
     #[inline(always)]
     pub fn pwr_rtcen_run(&self) -> PWR_RTCEN_RUN_R {
-        PWR_RTCEN_RUN_R::new(((self.bits >> 11) & 0x01) != 0)
+        PWR_RTCEN_RUN_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - Enable Real Time Clock Operation during Sleep Mode"]
     #[inline(always)]
     pub fn pwr_rtcen_slp(&self) -> PWR_RTCEN_SLP_R {
-        PWR_RTCEN_SLP_R::new(((self.bits >> 12) & 0x01) != 0)
+        PWR_RTCEN_SLP_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - Enable VDD12_SW SVM operation during Run Mode"]
     #[inline(always)]
     pub fn pwr_svm12en_run(&self) -> PWR_SVM12EN_RUN_R {
-        PWR_SVM12EN_RUN_R::new(((self.bits >> 13) & 0x01) != 0)
+        PWR_SVM12EN_RUN_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 15 - Enable VDD18_SW SVM operation during Run Mode"]
     #[inline(always)]
     pub fn pwr_svm18en_run(&self) -> PWR_SVM18EN_RUN_R {
-        PWR_SVM18EN_RUN_R::new(((self.bits >> 15) & 0x01) != 0)
+        PWR_SVM18EN_RUN_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 17 - Enable VRTC SVM operation during Run Mode"]
     #[inline(always)]
     pub fn pwr_svmrtcen_run(&self) -> PWR_SVMRTCEN_RUN_R {
-        PWR_SVMRTCEN_RUN_R::new(((self.bits >> 17) & 0x01) != 0)
+        PWR_SVMRTCEN_RUN_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 19 - Enable VDDB SVM operation during Run Mode"]
     #[inline(always)]
     pub fn pwr_svm_vddb_run(&self) -> PWR_SVM_VDDB_RUN_R {
-        PWR_SVM_VDDB_RUN_R::new(((self.bits >> 19) & 0x01) != 0)
+        PWR_SVM_VDDB_RUN_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 21 - Enable TVDD12 SVM operation during Run Mode"]
     #[inline(always)]
     pub fn pwr_svmtvdd12en_run(&self) -> PWR_SVMTVDD12EN_RUN_R {
-        PWR_SVMTVDD12EN_RUN_R::new(((self.bits >> 21) & 0x01) != 0)
+        PWR_SVMTVDD12EN_RUN_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 23 - Enable VDD12 switching during Run Mode"]
     #[inline(always)]
     pub fn pwr_vdd12_swen_run(&self) -> PWR_VDD12_SWEN_RUN_R {
-        PWR_VDD12_SWEN_RUN_R::new(((self.bits >> 23) & 0x01) != 0)
+        PWR_VDD12_SWEN_RUN_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 24 - Enable VDD12 switching during Sleep Mode"]
     #[inline(always)]
     pub fn pwr_vdd12_swen_slp(&self) -> PWR_VDD12_SWEN_SLP_R {
-        PWR_VDD12_SWEN_SLP_R::new(((self.bits >> 24) & 0x01) != 0)
+        PWR_VDD12_SWEN_SLP_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 25 - Enable VDD18 switching during Run Mode"]
     #[inline(always)]
     pub fn pwr_vdd18_swen_run(&self) -> PWR_VDD18_SWEN_RUN_R {
-        PWR_VDD18_SWEN_RUN_R::new(((self.bits >> 25) & 0x01) != 0)
+        PWR_VDD18_SWEN_RUN_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 26 - Enable VDD18 switching during Sleep Mode"]
     #[inline(always)]
     pub fn pwr_vdd18_swen_slp(&self) -> PWR_VDD18_SWEN_SLP_R {
-        PWR_VDD18_SWEN_SLP_R::new(((self.bits >> 26) & 0x01) != 0)
+        PWR_VDD18_SWEN_SLP_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 27 - Enable TVDD12 switching during Run Mode"]
     #[inline(always)]
     pub fn pwr_tvdd12_swen_run(&self) -> PWR_TVDD12_SWEN_RUN_R {
-        PWR_TVDD12_SWEN_RUN_R::new(((self.bits >> 27) & 0x01) != 0)
+        PWR_TVDD12_SWEN_RUN_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - Enable TVDD12 switching during Sleep Mode"]
     #[inline(always)]
     pub fn pwr_tvdd12_swen_slp(&self) -> PWR_TVDD12_SWEN_SLP_R {
-        PWR_TVDD12_SWEN_SLP_R::new(((self.bits >> 28) & 0x01) != 0)
+        PWR_TVDD12_SWEN_SLP_R::new(((self.bits >> 28) & 1) != 0)
     }
 }
 impl W {
