@@ -49,7 +49,7 @@ impl From<TX_FIFO_AE_A> for bool {
     }
 }
 #[doc = "Field `tx_fifo_ae` reader - TX FIFO Almost Empty Int Enable"]
-pub struct TX_FIFO_AE_R(crate::FieldReader<bool, TX_FIFO_AE_A>);
+pub struct TX_FIFO_AE_R(crate::FieldReader<bool>);
 impl TX_FIFO_AE_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -75,7 +75,7 @@ impl TX_FIFO_AE_R {
     }
 }
 impl core::ops::Deref for TX_FIFO_AE_R {
-    type Target = crate::FieldReader<bool, TX_FIFO_AE_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -114,7 +114,7 @@ impl<'a> TX_FIFO_AE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -133,7 +133,7 @@ impl From<RX_FIFO_AF_A> for bool {
     }
 }
 #[doc = "Field `rx_fifo_af` reader - RX FIFO Almost Full Int Enable"]
-pub struct RX_FIFO_AF_R(crate::FieldReader<bool, RX_FIFO_AF_A>);
+pub struct RX_FIFO_AF_R(crate::FieldReader<bool>);
 impl RX_FIFO_AF_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -159,7 +159,7 @@ impl RX_FIFO_AF_R {
     }
 }
 impl core::ops::Deref for RX_FIFO_AF_R {
-    type Target = crate::FieldReader<bool, RX_FIFO_AF_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -198,7 +198,7 @@ impl<'a> RX_FIFO_AF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -217,7 +217,7 @@ impl From<TX_NO_DATA_A> for bool {
     }
 }
 #[doc = "Field `tx_no_data` reader - No Data in TX FIFO Int Enable"]
-pub struct TX_NO_DATA_R(crate::FieldReader<bool, TX_NO_DATA_A>);
+pub struct TX_NO_DATA_R(crate::FieldReader<bool>);
 impl TX_NO_DATA_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -243,7 +243,7 @@ impl TX_NO_DATA_R {
     }
 }
 impl core::ops::Deref for TX_NO_DATA_R {
-    type Target = crate::FieldReader<bool, TX_NO_DATA_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -282,7 +282,7 @@ impl<'a> TX_NO_DATA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -301,7 +301,7 @@ impl From<RX_LOST_DATA_A> for bool {
     }
 }
 #[doc = "Field `rx_lost_data` reader - RX FIFO Overflow Int Enable"]
-pub struct RX_LOST_DATA_R(crate::FieldReader<bool, RX_LOST_DATA_A>);
+pub struct RX_LOST_DATA_R(crate::FieldReader<bool>);
 impl RX_LOST_DATA_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -327,7 +327,7 @@ impl RX_LOST_DATA_R {
     }
 }
 impl core::ops::Deref for RX_LOST_DATA_R {
-    type Target = crate::FieldReader<bool, RX_LOST_DATA_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -366,7 +366,7 @@ impl<'a> RX_LOST_DATA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
@@ -385,7 +385,7 @@ impl From<TX_UNDERFLOW_A> for bool {
     }
 }
 #[doc = "Field `tx_underflow` reader - TX Underflow Int Enable"]
-pub struct TX_UNDERFLOW_R(crate::FieldReader<bool, TX_UNDERFLOW_A>);
+pub struct TX_UNDERFLOW_R(crate::FieldReader<bool>);
 impl TX_UNDERFLOW_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -411,7 +411,7 @@ impl TX_UNDERFLOW_R {
     }
 }
 impl core::ops::Deref for TX_UNDERFLOW_R {
-    type Target = crate::FieldReader<bool, TX_UNDERFLOW_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -450,7 +450,7 @@ impl<'a> TX_UNDERFLOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
@@ -469,7 +469,7 @@ impl From<SS_ASSERTED_A> for bool {
     }
 }
 #[doc = "Field `ss_asserted` reader - Slave Select Asserted Int Enable"]
-pub struct SS_ASSERTED_R(crate::FieldReader<bool, SS_ASSERTED_A>);
+pub struct SS_ASSERTED_R(crate::FieldReader<bool>);
 impl SS_ASSERTED_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -495,7 +495,7 @@ impl SS_ASSERTED_R {
     }
 }
 impl core::ops::Deref for SS_ASSERTED_R {
-    type Target = crate::FieldReader<bool, SS_ASSERTED_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -534,7 +534,7 @@ impl<'a> SS_ASSERTED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
@@ -553,7 +553,7 @@ impl From<SS_DEASSERTED_A> for bool {
     }
 }
 #[doc = "Field `ss_deasserted` reader - Slave Select Deasserted Int Enable"]
-pub struct SS_DEASSERTED_R(crate::FieldReader<bool, SS_DEASSERTED_A>);
+pub struct SS_DEASSERTED_R(crate::FieldReader<bool>);
 impl SS_DEASSERTED_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -579,7 +579,7 @@ impl SS_DEASSERTED_R {
     }
 }
 impl core::ops::Deref for SS_DEASSERTED_R {
-    type Target = crate::FieldReader<bool, SS_DEASSERTED_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -618,7 +618,7 @@ impl<'a> SS_DEASSERTED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -626,37 +626,37 @@ impl R {
     #[doc = "Bit 0 - TX FIFO Almost Empty Int Enable"]
     #[inline(always)]
     pub fn tx_fifo_ae(&self) -> TX_FIFO_AE_R {
-        TX_FIFO_AE_R::new((self.bits & 0x01) != 0)
+        TX_FIFO_AE_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - RX FIFO Almost Full Int Enable"]
     #[inline(always)]
     pub fn rx_fifo_af(&self) -> RX_FIFO_AF_R {
-        RX_FIFO_AF_R::new(((self.bits >> 1) & 0x01) != 0)
+        RX_FIFO_AF_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - No Data in TX FIFO Int Enable"]
     #[inline(always)]
     pub fn tx_no_data(&self) -> TX_NO_DATA_R {
-        TX_NO_DATA_R::new(((self.bits >> 2) & 0x01) != 0)
+        TX_NO_DATA_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - RX FIFO Overflow Int Enable"]
     #[inline(always)]
     pub fn rx_lost_data(&self) -> RX_LOST_DATA_R {
-        RX_LOST_DATA_R::new(((self.bits >> 3) & 0x01) != 0)
+        RX_LOST_DATA_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - TX Underflow Int Enable"]
     #[inline(always)]
     pub fn tx_underflow(&self) -> TX_UNDERFLOW_R {
-        TX_UNDERFLOW_R::new(((self.bits >> 4) & 0x01) != 0)
+        TX_UNDERFLOW_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - Slave Select Asserted Int Enable"]
     #[inline(always)]
     pub fn ss_asserted(&self) -> SS_ASSERTED_R {
-        SS_ASSERTED_R::new(((self.bits >> 5) & 0x01) != 0)
+        SS_ASSERTED_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - Slave Select Deasserted Int Enable"]
     #[inline(always)]
     pub fn ss_deasserted(&self) -> SS_DEASSERTED_R {
-        SS_DEASSERTED_R::new(((self.bits >> 6) & 0x01) != 0)
+        SS_DEASSERTED_R::new(((self.bits >> 6) & 1) != 0)
     }
 }
 impl W {
