@@ -50,7 +50,7 @@ impl From<SPI_MODE_A> for u8 {
     }
 }
 #[doc = "Field `spi_mode` reader - SPIX Mode"]
-pub struct SPI_MODE_R(crate::FieldReader<u8, SPI_MODE_A>);
+pub struct SPI_MODE_R(crate::FieldReader<u8>);
 impl SPI_MODE_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -77,7 +77,7 @@ impl SPI_MODE_R {
     }
 }
 impl core::ops::Deref for SPI_MODE_R {
-    type Target = crate::FieldReader<u8, SPI_MODE_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -106,7 +106,7 @@ impl<'a> SPI_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
+        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
         self.w
     }
 }
@@ -125,7 +125,7 @@ impl From<SS_ACT_LO_A> for bool {
     }
 }
 #[doc = "Field `ss_act_lo` reader - SPIX Slave Select Polarity"]
-pub struct SS_ACT_LO_R(crate::FieldReader<bool, SS_ACT_LO_A>);
+pub struct SS_ACT_LO_R(crate::FieldReader<bool>);
 impl SS_ACT_LO_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -151,7 +151,7 @@ impl SS_ACT_LO_R {
     }
 }
 impl core::ops::Deref for SS_ACT_LO_R {
-    type Target = crate::FieldReader<bool, SS_ACT_LO_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -190,7 +190,7 @@ impl<'a> SS_ACT_LO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -209,7 +209,7 @@ impl From<ALT_TIMING_EN_A> for bool {
     }
 }
 #[doc = "Field `alt_timing_en` reader - Alternate Timing Mode Enable"]
-pub struct ALT_TIMING_EN_R(crate::FieldReader<bool, ALT_TIMING_EN_A>);
+pub struct ALT_TIMING_EN_R(crate::FieldReader<bool>);
 impl ALT_TIMING_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -235,7 +235,7 @@ impl ALT_TIMING_EN_R {
     }
 }
 impl core::ops::Deref for ALT_TIMING_EN_R {
-    type Target = crate::FieldReader<bool, ALT_TIMING_EN_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -274,12 +274,12 @@ impl<'a> ALT_TIMING_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `slave_sel` reader - SPIX Slave Select"]
-pub struct SLAVE_SEL_R(crate::FieldReader<u8, u8>);
+pub struct SLAVE_SEL_R(crate::FieldReader<u8>);
 impl SLAVE_SEL_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -287,7 +287,7 @@ impl SLAVE_SEL_R {
     }
 }
 impl core::ops::Deref for SLAVE_SEL_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -301,12 +301,12 @@ impl<'a> SLAVE_SEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 4)) | ((value as u32 & 0x07) << 4);
+        self.w.bits = (self.w.bits & !(7 << 4)) | ((value as u32 & 7) << 4);
         self.w
     }
 }
 #[doc = "Field `sck_hi_clk` reader - SCK High Clocks"]
-pub struct SCK_HI_CLK_R(crate::FieldReader<u8, u8>);
+pub struct SCK_HI_CLK_R(crate::FieldReader<u8>);
 impl SCK_HI_CLK_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -314,7 +314,7 @@ impl SCK_HI_CLK_R {
     }
 }
 impl core::ops::Deref for SCK_HI_CLK_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -333,7 +333,7 @@ impl<'a> SCK_HI_CLK_W<'a> {
     }
 }
 #[doc = "Field `sck_lo_clk` reader - SCK Low Clocks"]
-pub struct SCK_LO_CLK_R(crate::FieldReader<u8, u8>);
+pub struct SCK_LO_CLK_R(crate::FieldReader<u8>);
 impl SCK_LO_CLK_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -341,7 +341,7 @@ impl SCK_LO_CLK_R {
     }
 }
 impl core::ops::Deref for SCK_LO_CLK_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -379,7 +379,7 @@ impl From<ACT_DELAY_A> for u8 {
     }
 }
 #[doc = "Field `act_delay` reader - SS Active Timing"]
-pub struct ACT_DELAY_R(crate::FieldReader<u8, ACT_DELAY_A>);
+pub struct ACT_DELAY_R(crate::FieldReader<u8>);
 impl ACT_DELAY_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -418,7 +418,7 @@ impl ACT_DELAY_R {
     }
 }
 impl core::ops::Deref for ACT_DELAY_R {
-    type Target = crate::FieldReader<u8, ACT_DELAY_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -457,7 +457,7 @@ impl<'a> ACT_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 16)) | ((value as u32 & 0x03) << 16);
+        self.w.bits = (self.w.bits & !(3 << 16)) | ((value as u32 & 3) << 16);
         self.w
     }
 }
@@ -481,7 +481,7 @@ impl From<INACT_DELAY_A> for u8 {
     }
 }
 #[doc = "Field `inact_delay` reader - SS Inactive Timing"]
-pub struct INACT_DELAY_R(crate::FieldReader<u8, INACT_DELAY_A>);
+pub struct INACT_DELAY_R(crate::FieldReader<u8>);
 impl INACT_DELAY_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -520,7 +520,7 @@ impl INACT_DELAY_R {
     }
 }
 impl core::ops::Deref for INACT_DELAY_R {
-    type Target = crate::FieldReader<u8, INACT_DELAY_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -559,12 +559,12 @@ impl<'a> INACT_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 18)) | ((value as u32 & 0x03) << 18);
+        self.w.bits = (self.w.bits & !(3 << 18)) | ((value as u32 & 3) << 18);
         self.w
     }
 }
 #[doc = "Field `alt_sck_hi_clk` reader - Alt SCK High Clocks"]
-pub struct ALT_SCK_HI_CLK_R(crate::FieldReader<u8, u8>);
+pub struct ALT_SCK_HI_CLK_R(crate::FieldReader<u8>);
 impl ALT_SCK_HI_CLK_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -572,7 +572,7 @@ impl ALT_SCK_HI_CLK_R {
     }
 }
 impl core::ops::Deref for ALT_SCK_HI_CLK_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -591,7 +591,7 @@ impl<'a> ALT_SCK_HI_CLK_W<'a> {
     }
 }
 #[doc = "Field `alt_sck_lo_clk` reader - Alt SCK Low Clocks"]
-pub struct ALT_SCK_LO_CLK_R(crate::FieldReader<u8, u8>);
+pub struct ALT_SCK_LO_CLK_R(crate::FieldReader<u8>);
 impl ALT_SCK_LO_CLK_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -599,7 +599,7 @@ impl ALT_SCK_LO_CLK_R {
     }
 }
 impl core::ops::Deref for ALT_SCK_LO_CLK_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -621,22 +621,22 @@ impl R {
     #[doc = "Bits 0:1 - SPIX Mode"]
     #[inline(always)]
     pub fn spi_mode(&self) -> SPI_MODE_R {
-        SPI_MODE_R::new((self.bits & 0x03) as u8)
+        SPI_MODE_R::new((self.bits & 3) as u8)
     }
     #[doc = "Bit 2 - SPIX Slave Select Polarity"]
     #[inline(always)]
     pub fn ss_act_lo(&self) -> SS_ACT_LO_R {
-        SS_ACT_LO_R::new(((self.bits >> 2) & 0x01) != 0)
+        SS_ACT_LO_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - Alternate Timing Mode Enable"]
     #[inline(always)]
     pub fn alt_timing_en(&self) -> ALT_TIMING_EN_R {
-        ALT_TIMING_EN_R::new(((self.bits >> 3) & 0x01) != 0)
+        ALT_TIMING_EN_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bits 4:6 - SPIX Slave Select"]
     #[inline(always)]
     pub fn slave_sel(&self) -> SLAVE_SEL_R {
-        SLAVE_SEL_R::new(((self.bits >> 4) & 0x07) as u8)
+        SLAVE_SEL_R::new(((self.bits >> 4) & 7) as u8)
     }
     #[doc = "Bits 8:11 - SCK High Clocks"]
     #[inline(always)]
@@ -651,12 +651,12 @@ impl R {
     #[doc = "Bits 16:17 - SS Active Timing"]
     #[inline(always)]
     pub fn act_delay(&self) -> ACT_DELAY_R {
-        ACT_DELAY_R::new(((self.bits >> 16) & 0x03) as u8)
+        ACT_DELAY_R::new(((self.bits >> 16) & 3) as u8)
     }
     #[doc = "Bits 18:19 - SS Inactive Timing"]
     #[inline(always)]
     pub fn inact_delay(&self) -> INACT_DELAY_R {
-        INACT_DELAY_R::new(((self.bits >> 18) & 0x03) as u8)
+        INACT_DELAY_R::new(((self.bits >> 18) & 3) as u8)
     }
     #[doc = "Bits 20:23 - Alt SCK High Clocks"]
     #[inline(always)]
