@@ -35,7 +35,7 @@ impl From<crate::W<DEV_INTEN_SPEC>> for W {
     }
 }
 #[doc = "Field `dpact` reader - DPLUS Activity Interrupt Flag"]
-pub struct DPACT_R(crate::FieldReader<bool, bool>);
+pub struct DPACT_R(crate::FieldReader<bool>);
 impl DPACT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl DPACT_R {
     }
 }
 impl core::ops::Deref for DPACT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,12 +67,12 @@ impl<'a> DPACT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `rwu_dn` reader - Remote Wakeup Done Interrupt Flag"]
-pub struct RWU_DN_R(crate::FieldReader<bool, bool>);
+pub struct RWU_DN_R(crate::FieldReader<bool>);
 impl RWU_DN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -80,7 +80,7 @@ impl RWU_DN_R {
     }
 }
 impl core::ops::Deref for RWU_DN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -104,12 +104,12 @@ impl<'a> RWU_DN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `bact` reader - USB Bus Activity Interrupt Flag"]
-pub struct BACT_R(crate::FieldReader<bool, bool>);
+pub struct BACT_R(crate::FieldReader<bool>);
 impl BACT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -117,7 +117,7 @@ impl BACT_R {
     }
 }
 impl core::ops::Deref for BACT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -141,12 +141,12 @@ impl<'a> BACT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `brst` reader - USB Bus Reset In Progress Interrupt Flag"]
-pub struct BRST_R(crate::FieldReader<bool, bool>);
+pub struct BRST_R(crate::FieldReader<bool>);
 impl BRST_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -154,7 +154,7 @@ impl BRST_R {
     }
 }
 impl core::ops::Deref for BRST_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -178,12 +178,12 @@ impl<'a> BRST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `susp` reader - USB Suspend Interrupt Flag"]
-pub struct SUSP_R(crate::FieldReader<bool, bool>);
+pub struct SUSP_R(crate::FieldReader<bool>);
 impl SUSP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -191,7 +191,7 @@ impl SUSP_R {
     }
 }
 impl core::ops::Deref for SUSP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -215,12 +215,12 @@ impl<'a> SUSP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `no_vbus` reader - No VBUS Interrupt Flag"]
-pub struct NO_VBUS_R(crate::FieldReader<bool, bool>);
+pub struct NO_VBUS_R(crate::FieldReader<bool>);
 impl NO_VBUS_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -228,7 +228,7 @@ impl NO_VBUS_R {
     }
 }
 impl core::ops::Deref for NO_VBUS_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -252,12 +252,12 @@ impl<'a> NO_VBUS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `vbus` reader - VBUS Detect Interrupt Flag"]
-pub struct VBUS_R(crate::FieldReader<bool, bool>);
+pub struct VBUS_R(crate::FieldReader<bool>);
 impl VBUS_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -265,7 +265,7 @@ impl VBUS_R {
     }
 }
 impl core::ops::Deref for VBUS_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -289,12 +289,12 @@ impl<'a> VBUS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `brst_dn` reader - USB Bus Reset Completed Interrupt Flag"]
-pub struct BRST_DN_R(crate::FieldReader<bool, bool>);
+pub struct BRST_DN_R(crate::FieldReader<bool>);
 impl BRST_DN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -302,7 +302,7 @@ impl BRST_DN_R {
     }
 }
 impl core::ops::Deref for BRST_DN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -326,12 +326,12 @@ impl<'a> BRST_DN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `setup` reader - Setup Packet Interrupt Flag"]
-pub struct SETUP_R(crate::FieldReader<bool, bool>);
+pub struct SETUP_R(crate::FieldReader<bool>);
 impl SETUP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -339,7 +339,7 @@ impl SETUP_R {
     }
 }
 impl core::ops::Deref for SETUP_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -363,12 +363,12 @@ impl<'a> SETUP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `ep_in` reader - Endpoint IN Interrupt Flag"]
-pub struct EP_IN_R(crate::FieldReader<bool, bool>);
+pub struct EP_IN_R(crate::FieldReader<bool>);
 impl EP_IN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -376,7 +376,7 @@ impl EP_IN_R {
     }
 }
 impl core::ops::Deref for EP_IN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -400,12 +400,12 @@ impl<'a> EP_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `ep_out` reader - Endpoint OUT Interrupt Flag"]
-pub struct EP_OUT_R(crate::FieldReader<bool, bool>);
+pub struct EP_OUT_R(crate::FieldReader<bool>);
 impl EP_OUT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -413,7 +413,7 @@ impl EP_OUT_R {
     }
 }
 impl core::ops::Deref for EP_OUT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -437,12 +437,12 @@ impl<'a> EP_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `ep_nak` reader - Endpoint NAK Interrupt Flag"]
-pub struct EP_NAK_R(crate::FieldReader<bool, bool>);
+pub struct EP_NAK_R(crate::FieldReader<bool>);
 impl EP_NAK_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -450,7 +450,7 @@ impl EP_NAK_R {
     }
 }
 impl core::ops::Deref for EP_NAK_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -474,12 +474,12 @@ impl<'a> EP_NAK_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `dma_err` reader - DMA Error Interrupt Flag"]
-pub struct DMA_ERR_R(crate::FieldReader<bool, bool>);
+pub struct DMA_ERR_R(crate::FieldReader<bool>);
 impl DMA_ERR_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -487,7 +487,7 @@ impl DMA_ERR_R {
     }
 }
 impl core::ops::Deref for DMA_ERR_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -511,12 +511,12 @@ impl<'a> DMA_ERR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `buf_ovr` reader - Buffer Overflow Interrupt Flag"]
-pub struct BUF_OVR_R(crate::FieldReader<bool, bool>);
+pub struct BUF_OVR_R(crate::FieldReader<bool>);
 impl BUF_OVR_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -524,7 +524,7 @@ impl BUF_OVR_R {
     }
 }
 impl core::ops::Deref for BUF_OVR_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -548,7 +548,7 @@ impl<'a> BUF_OVR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -556,72 +556,72 @@ impl R {
     #[doc = "Bit 0 - DPLUS Activity Interrupt Flag"]
     #[inline(always)]
     pub fn dpact(&self) -> DPACT_R {
-        DPACT_R::new((self.bits & 0x01) != 0)
+        DPACT_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - Remote Wakeup Done Interrupt Flag"]
     #[inline(always)]
     pub fn rwu_dn(&self) -> RWU_DN_R {
-        RWU_DN_R::new(((self.bits >> 1) & 0x01) != 0)
+        RWU_DN_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - USB Bus Activity Interrupt Flag"]
     #[inline(always)]
     pub fn bact(&self) -> BACT_R {
-        BACT_R::new(((self.bits >> 2) & 0x01) != 0)
+        BACT_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - USB Bus Reset In Progress Interrupt Flag"]
     #[inline(always)]
     pub fn brst(&self) -> BRST_R {
-        BRST_R::new(((self.bits >> 3) & 0x01) != 0)
+        BRST_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - USB Suspend Interrupt Flag"]
     #[inline(always)]
     pub fn susp(&self) -> SUSP_R {
-        SUSP_R::new(((self.bits >> 4) & 0x01) != 0)
+        SUSP_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - No VBUS Interrupt Flag"]
     #[inline(always)]
     pub fn no_vbus(&self) -> NO_VBUS_R {
-        NO_VBUS_R::new(((self.bits >> 5) & 0x01) != 0)
+        NO_VBUS_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - VBUS Detect Interrupt Flag"]
     #[inline(always)]
     pub fn vbus(&self) -> VBUS_R {
-        VBUS_R::new(((self.bits >> 6) & 0x01) != 0)
+        VBUS_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - USB Bus Reset Completed Interrupt Flag"]
     #[inline(always)]
     pub fn brst_dn(&self) -> BRST_DN_R {
-        BRST_DN_R::new(((self.bits >> 7) & 0x01) != 0)
+        BRST_DN_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - Setup Packet Interrupt Flag"]
     #[inline(always)]
     pub fn setup(&self) -> SETUP_R {
-        SETUP_R::new(((self.bits >> 8) & 0x01) != 0)
+        SETUP_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - Endpoint IN Interrupt Flag"]
     #[inline(always)]
     pub fn ep_in(&self) -> EP_IN_R {
-        EP_IN_R::new(((self.bits >> 9) & 0x01) != 0)
+        EP_IN_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - Endpoint OUT Interrupt Flag"]
     #[inline(always)]
     pub fn ep_out(&self) -> EP_OUT_R {
-        EP_OUT_R::new(((self.bits >> 10) & 0x01) != 0)
+        EP_OUT_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - Endpoint NAK Interrupt Flag"]
     #[inline(always)]
     pub fn ep_nak(&self) -> EP_NAK_R {
-        EP_NAK_R::new(((self.bits >> 11) & 0x01) != 0)
+        EP_NAK_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - DMA Error Interrupt Flag"]
     #[inline(always)]
     pub fn dma_err(&self) -> DMA_ERR_R {
-        DMA_ERR_R::new(((self.bits >> 12) & 0x01) != 0)
+        DMA_ERR_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - Buffer Overflow Interrupt Flag"]
     #[inline(always)]
     pub fn buf_ovr(&self) -> BUF_OVR_R {
-        BUF_OVR_R::new(((self.bits >> 13) & 0x01) != 0)
+        BUF_OVR_R::new(((self.bits >> 13) & 1) != 0)
     }
 }
 impl W {
